#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'MrSteam v3'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        97,
        105,
        110,
        105,
        110,
        103,
        82,
        117,
        110,
        116,
        105,
        109,
        101,
    ]
)
AHEOCT = "".join(chr(c) for c in [65, 108, 108])
AKQXPI = "".join(
    chr(c) for c in [85, 115, 101, 114, 86, 97, 108, 118, 101, 80, 111, 119, 101, 114]
)
AMJMAO = 292
AOAWBS = 336
AONPYY = "".join(chr(c) for c in [83, 67, 95, 53, 52])
ASSAKQ = "".join(chr(c) for c in [80, 114, 111, 103, 49])
AWBSIR = 337
BFEGZU = "".join(chr(c) for c in [83, 108, 97, 118, 101, 72, 50, 79, 50, 69, 114, 114])
BIAMJM = 291
BLKXSJ = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 73, 68])
BMJVHF = "".join(chr(c) for c in [79, 78])
BSIRYX = "".join(chr(c) for c in [76, 73])
BSKSOK = 0
BWJYKL = "".join(
    chr(c) for c in [67, 111, 108, 111, 114, 95, 75, 101, 121, 112, 97, 100]
)
CBFEGZ = "".join(chr(c) for c in [72, 50, 79, 50, 69, 114, 114])
CCPQIP = 293
CPQIPO = "".join(
    chr(c)
    for c in [68, 114, 97, 105, 110, 86, 97, 108, 118, 101, 79, 117, 116, 112, 117, 116]
)
CQBMJV = 256
CTHBSK = 268
CWAONP = 277
CXQIEF = 304
ECVYYP = 258
EFJTAC = "".join(chr(c) for c in [82, 111, 111, 109, 84, 101, 109, 112, 71])
EFXQGL = 307
EGZUQE = "".join(chr(c) for c in [70, 108, 97, 115, 104, 69, 114, 114])
EKCWAO = 275
EOCTHB = 311
EXLSXU = "".join(chr(c) for c in [74, 117, 109, 112, 101, 114, 57])
FEFJTA = 301
FEGZUQ = "".join(chr(c) for c in [75, 101, 121, 83, 116, 117, 99, 107, 69, 114, 114])
FJBIAM = 290
FJTACC = 278
FTHECV = 257
FTSIFJ = 287
FXQGLR = "".join(
    chr(c)
    for c in [85, 115, 101, 114, 86, 97, 108, 118, 101, 84, 101, 109, 112, 85, 112]
)
GLRAHE = 309
GQPLSP = "".join(chr(c) for c in [49, 54, 75])
GYOUSP = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
GZUQEX = "".join(chr(c) for c in [80, 114, 114, 51, 69, 114, 114])
HBSKSO = 269
HECVYY = "".join(chr(c) for c in [85, 115, 101, 114, 65, 114, 111, 109, 97])
HEOCTH = "".join(
    chr(c)
    for c in [
        85,
        115,
        101,
        114,
        86,
        97,
        108,
        118,
        101,
        65,
        117,
        116,
        111,
        67,
        108,
        101,
        97,
        110,
    ]
)
HFTHEC = "".join(chr(c) for c in [85, 115, 101, 114, 80, 97, 117, 115, 101])
HUOJRJ = 4
IAMJMA = "".join(
    chr(c) for c in [80, 97, 99, 107, 83, 116, 97, 116, 117, 115, 76, 105, 98]
)
ICXQIE = "".join(
    chr(c)
    for c in [
        85,
        115,
        101,
        114,
        86,
        97,
        108,
        118,
        101,
        68,
        105,
        115,
        105,
        110,
        102,
        101,
        99,
        116,
        105,
        111,
        110,
    ]
)
IEFXQG = "".join(
    chr(c)
    for c in [
        85,
        115,
        101,
        114,
        86,
        97,
        108,
        118,
        101,
        70,
        108,
        111,
        119,
        68,
        111,
        119,
        110,
    ]
)
IFJBIA = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
IGYOUS = "".join(chr(c) for c in [68, 74, 83, 52])
IPIVLA = "".join(chr(c) for c in [85, 115, 101, 114, 82, 117, 110, 116, 105, 109, 101])
IPOUYN = "".join(
    chr(c) for c in [72, 101, 97, 116, 101, 114, 79, 117, 116, 112, 117, 116]
)
IRYXBQ = 256
IUSOOQ = 6
IUXFEF = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 118])
IVLASS = "".join(chr(c) for c in [85, 115, 101, 114, 80, 114, 111, 103])
JBIAMJ = "".join(
    chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
)
JHIUSO = "".join(chr(c) for c in [77, 65, 83, 84, 69, 82])
JIGYOU = "".join(chr(c) for c in [77, 73, 65])
JMAOAW = 334
JMCBFE = "".join(chr(c) for c in [80, 114, 114, 50, 69, 114, 114])
JRJHIU = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 83, 108, 97, 118, 101])
JTACCP = "".join(chr(c) for c in [75, 49, 48, 48, 48, 84, 101, 109, 112, 71])
JUTYEK = "".join(chr(c) for c in [74, 117, 109, 112, 101, 114, 54])
JWMNZM = 284
JYKLGQ = "".join(chr(c) for c in [77, 114, 83, 116, 101, 97, 109])
JYMOUN = "".join(
    chr(c) for c in [83, 104, 111, 119, 101, 114, 70, 108, 111, 119, 82, 97, 116, 101]
)
KCWAON = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 84, 121, 112, 101])
KLGQPL = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
KPHUOJ = 3
KQXPIC = 302
KSOKPH = "".join(chr(c) for c in [80, 97, 117, 115, 101, 83, 116, 97, 116, 101])
KXSJWM = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 118])
LASSAK = "".join(chr(c) for c in [85, 115, 101, 114])
LGQPLS = 286
LIUXFE = 298
LKXSJW = 281
LRAHEO = "".join(
    chr(c)
    for c in [
        85,
        115,
        101,
        114,
        86,
        97,
        108,
        118,
        101,
        76,
        101,
        97,
        114,
        110,
        105,
        110,
        103,
    ]
)
LSPFTS = "".join(chr(c) for c in [54, 52, 75])
LSXUJU = "".join(chr(c) for c in [74, 117, 109, 112, 101, 114, 50])
MAOAWB = "".join(
    chr(c)
    for c in [
        73,
        50,
        67,
        116,
        111,
        82,
        83,
        52,
        56,
        53,
        67,
        111,
        110,
        118,
        101,
        114,
        116,
        101,
        114,
        82,
        101,
        118,
    ]
)
MCBFEG = "".join(chr(c) for c in [80, 114, 114, 49, 69, 114, 114])
MJIGYO = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
MJMAOA = "".join(
    chr(c)
    for c in [
        73,
        50,
        67,
        116,
        111,
        82,
        83,
        52,
        56,
        53,
        67,
        111,
        110,
        118,
        101,
        114,
        116,
        101,
        114,
        73,
        68,
    ]
)
MJVHFT = "".join(chr(c) for c in [68, 73, 65, 71, 78, 79, 83, 84, 73, 67])
MNZMJI = 285
MOUNBL = "".join(
    chr(c)
    for c in [65, 118, 97, 105, 108, 97, 98, 108, 101, 79, 117, 116, 108, 101, 116]
)
NBLKXS = 322
NPYYLI = "".join(chr(c) for c in [65, 85, 88, 95, 83, 87])
NQJYMO = "".join(
    chr(c)
    for c in [83, 104, 111, 119, 101, 114, 86, 97, 108, 118, 101, 84, 101, 109, 112, 67]
)
NRSJMC = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 72, 101, 97, 116, 101, 114, 83, 116, 97, 116, 101]
)
NZMJIG = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
OAWBSI = "".join(
    chr(c)
    for c in [
        73,
        50,
        67,
        116,
        111,
        82,
        83,
        52,
        56,
        53,
        67,
        111,
        110,
        118,
        101,
        114,
        116,
        101,
        114,
        82,
        101,
        108,
    ]
)
OCTHBS = "".join(chr(c) for c in [72, 111, 117, 114, 115])
OJRJHI = 5
OKPHUO = "".join(
    chr(c) for c in [69, 120, 116, 101, 114, 110, 97, 108, 80, 114, 111, 98, 101]
)
ONPYYL = "".join(chr(c) for c in [84, 83, 67, 95, 53, 51])
OOQNRS = "".join(
    chr(c) for c in [69, 120, 112, 114, 101, 115, 115, 67, 121, 99, 108, 101]
)
OQNRSJ = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 79, 110, 83, 116, 97, 116, 101]
)
OUNBLK = 318
OUSPBW = "".join(chr(c) for c in [75, 54, 48, 48])
OUYNQJ = "".join(
    chr(c) for c in [67, 104, 114, 111, 109, 97, 79, 117, 116, 112, 117, 116]
)
PBWJYK = "".join(chr(c) for c in [105, 110, 89, 84])
PFTSIF = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
PHUOJR = "".join(
    chr(c) for c in [87, 97, 116, 101, 114, 68, 101, 116, 101, 99, 116, 101, 100]
)
PICXQI = 303
PIPIVL = 264
PIVLAS = 261
PLSPFT = "".join(chr(c) for c in [52, 56, 75])
POUYNQ = "".join(
    chr(c)
    for c in [87, 97, 116, 101, 114, 86, 97, 108, 118, 101, 79, 117, 116, 112, 117, 116]
)
PQIPOU = 295
PYYLIU = "".join(chr(c) for c in [67, 79, 76, 79, 82, 95, 83, 69, 82, 73, 69, 83])
QBMJVH = "".join(chr(c) for c in [79, 70, 70])
QEXLSX = 273
QGLRAH = "".join(
    chr(c)
    for c in [
        85,
        115,
        101,
        114,
        86,
        97,
        108,
        118,
        101,
        84,
        101,
        109,
        112,
        68,
        111,
        119,
        110,
    ]
)
QIEFXQ = 306
QIPOUY = "".join(chr(c) for c in [65, 114, 111, 109, 97, 79, 117, 116, 112, 117, 116])
QJYMOU = 314
QNRSJM = 271
QPLSPF = "".join(chr(c) for c in [51, 50, 75])
RAHEOC = 310
RJHIUS = "".join(chr(c) for c in [83, 76, 65, 86, 69])
RSJMCB = "".join(
    chr(c) for c in [80, 111, 119, 101, 114, 70, 97, 105, 108, 69, 114, 114]
)
RYXBQF = 337
SIFJBI = 289
SJMCBF = 272
SJWMNZ = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 108])
SKSOKP = 2
SOKPHU = "".join(
    chr(c)
    for c in [68, 105, 97, 103, 110, 111, 115, 116, 105, 99, 83, 116, 97, 116, 101]
)
SOOQNR = 270
SPBWJY = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
SSAKQX = "".join(chr(c) for c in [80, 114, 111, 103, 50])
SXUJUT = "".join(chr(c) for c in [74, 117, 109, 112, 101, 114, 51])
TACCPQ = 296
THBSKS = "".join(chr(c) for c in [77, 111, 100, 101, 83, 116, 97, 116, 101])
THECVY = 1
TSIFJB = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
TYEKCW = "".join(chr(c) for c in [74, 117, 109, 112, 101, 114, 56])
UJUTYE = "".join(chr(c) for c in [74, 117, 109, 112, 101, 114, 53])
UNBLKX = "".join(
    chr(c)
    for c in [83, 104, 111, 119, 101, 114, 86, 97, 108, 118, 101, 65, 108, 97, 114, 109]
)
UOJRJH = "".join(
    chr(c) for c in [78, 111, 82, 101, 103, 117, 108, 97, 116, 105, 111, 110]
)
UQEXLS = "".join(chr(c) for c in [80, 114, 114, 52, 69, 114, 114])
USOOQN = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 80, 114, 111, 98, 101])
USPBWJ = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
UTYEKC = "".join(chr(c) for c in [74, 117, 109, 112, 101, 114, 55])
UXFEFJ = 300
UYNQJY = "".join(
    chr(c)
    for c in [
        83,
        104,
        111,
        119,
        101,
        114,
        86,
        97,
        108,
        118,
        101,
        83,
        116,
        97,
        116,
        117,
        115,
    ]
)
VHFTHE = "".join(chr(c) for c in [65, 76, 76])
VLASSA = 263
VYYPIP = "".join(chr(c) for c in [85, 115, 101, 114, 67, 104, 114, 111, 109, 97])
WAONPY = "".join(chr(c) for c in [78, 79, 95, 84, 83, 67])
WJYKLG = "".join(chr(c) for c in [105, 110, 89, 74])
WMNZMJ = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
XFEFJT = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 108])
XLSXUJ = 274
XPICXQ = "".join(
    chr(c)
    for c in [85, 115, 101, 114, 86, 97, 108, 118, 101, 79, 117, 116, 112, 117, 116]
)
XQGLRA = 308
XQIEFX = "".join(
    chr(c)
    for c in [85, 115, 101, 114, 86, 97, 108, 118, 101, 70, 108, 111, 119, 85, 112]
)
XSJWMN = 283
XUJUTY = "".join(chr(c) for c in [74, 117, 109, 112, 101, 114, 52])
YEKCWA = "".join(chr(c) for c in [77, 97, 120, 82, 117, 110, 116, 105, 109, 101])
YLIUXF = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 73, 68])
YMOUNB = 316
YNQJYM = 312
YOUSPB = "".join(chr(c) for c in [105, 110, 88, 77])
YPIPIV = "".join(
    chr(c) for c in [85, 115, 101, 114, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
YYPIPI = 259
ZCQBMJ = "".join(chr(c) for c in [85, 115, 101, 114, 77, 111, 100, 101])
ZMJIGY = "".join(chr(c) for c in [105, 110, 88, 69])
ZUQEXL = 7
CVYYPI = [QBMJVH, BMJVHF]
HIUSOO = [RJHIUS, JHIUSO]
JVHFTH = [QBMJVH, BMJVHF, MJVHFT]
QXPICX = [BMJVHF, QBMJVH]
SAKQXP = [LASSAK, ASSAKQ, SSAKQX]
SIRYXB = [BSIRYX]
SPFTSI = [GQPLSP, QPLSPF, PLSPFT, LSPFTS]
WBSIRY = []
YKLGQP = [
    NZMJIG,
    ZMJIGY,
    MJIGYO,
    JIGYOU,
    IGYOUS,
    GYOUSP,
    YOUSPB,
    OUSPBW,
    USPBWJ,
    SPBWJY,
    PBWJYK,
    BWJYKL,
    WJYKLG,
    JYKLGQ,
]
YYLIUX = [WAONPY, AONPYY, ONPYYL, NPYYLI, PYYLIU]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return KPHUOJ

    @property
    def begin(self):
        return IRYXBQ

    @property
    def end(self):
        return RYXBQF

    @property
    def all_device_keys(self):
        return SIRYXB

    @property
    def user_demand_keys(self):
        return WBSIRY

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoEnumStructAccessor(
                self.struct, ZCQBMJ, CQBMJV, None, JVHFTH, None, None, VHFTHE
            ),
            HFTHEC: GeckoBoolStructAccessor(
                self.struct, HFTHEC, FTHECV, THECVY, VHFTHE
            ),
            HECVYY: GeckoEnumStructAccessor(
                self.struct, HECVYY, ECVYYP, None, CVYYPI, None, None, VHFTHE
            ),
            VYYPIP: GeckoEnumStructAccessor(
                self.struct, VYYPIP, YYPIPI, None, CVYYPI, None, None, VHFTHE
            ),
            YPIPIV: GeckoTempStructAccessor(self.struct, YPIPIV, PIPIVL, VHFTHE),
            IPIVLA: GeckoWordStructAccessor(self.struct, IPIVLA, PIVLAS, VHFTHE),
            IVLASS: GeckoEnumStructAccessor(
                self.struct, IVLASS, VLASSA, None, SAKQXP, None, None, VHFTHE
            ),
            AKQXPI: GeckoEnumStructAccessor(
                self.struct, AKQXPI, KQXPIC, None, QXPICX, None, None, VHFTHE
            ),
            XPICXQ: GeckoByteStructAccessor(self.struct, XPICXQ, PICXQI, VHFTHE),
            ICXQIE: GeckoBoolStructAccessor(self.struct, ICXQIE, CXQIEF, None, VHFTHE),
            XQIEFX: GeckoBoolStructAccessor(self.struct, XQIEFX, QIEFXQ, None, VHFTHE),
            IEFXQG: GeckoBoolStructAccessor(self.struct, IEFXQG, EFXQGL, None, VHFTHE),
            FXQGLR: GeckoBoolStructAccessor(self.struct, FXQGLR, XQGLRA, None, VHFTHE),
            QGLRAH: GeckoBoolStructAccessor(self.struct, QGLRAH, GLRAHE, None, VHFTHE),
            LRAHEO: GeckoBoolStructAccessor(self.struct, LRAHEO, RAHEOC, None, AHEOCT),
            HEOCTH: GeckoBoolStructAccessor(self.struct, HEOCTH, EOCTHB, None, AHEOCT),
            OCTHBS: GeckoByteStructAccessor(self.struct, OCTHBS, CTHBSK, None),
            THBSKS: GeckoEnumStructAccessor(
                self.struct, THBSKS, HBSKSO, BSKSOK, CVYYPI, None, SKSOKP, None
            ),
            KSOKPH: GeckoBoolStructAccessor(self.struct, KSOKPH, HBSKSO, THECVY, None),
            SOKPHU: GeckoEnumStructAccessor(
                self.struct, SOKPHU, HBSKSO, SKSOKP, CVYYPI, None, SKSOKP, None
            ),
            OKPHUO: GeckoBoolStructAccessor(self.struct, OKPHUO, HBSKSO, KPHUOJ, None),
            PHUOJR: GeckoBoolStructAccessor(self.struct, PHUOJR, HBSKSO, HUOJRJ, None),
            UOJRJH: GeckoBoolStructAccessor(self.struct, UOJRJH, HBSKSO, OJRJHI, None),
            JRJHIU: GeckoEnumStructAccessor(
                self.struct, JRJHIU, HBSKSO, IUSOOQ, HIUSOO, None, SKSOKP, None
            ),
            USOOQN: GeckoBoolStructAccessor(self.struct, USOOQN, SOOQNR, BSKSOK, None),
            OOQNRS: GeckoBoolStructAccessor(self.struct, OOQNRS, SOOQNR, THECVY, None),
            OQNRSJ: GeckoBoolStructAccessor(self.struct, OQNRSJ, QNRSJM, THECVY, None),
            NRSJMC: GeckoEnumStructAccessor(
                self.struct, NRSJMC, QNRSJM, KPHUOJ, CVYYPI, None, SKSOKP, None
            ),
            RSJMCB: GeckoBoolStructAccessor(self.struct, RSJMCB, SJMCBF, BSKSOK, None),
            JMCBFE: GeckoBoolStructAccessor(self.struct, JMCBFE, SJMCBF, THECVY, None),
            MCBFEG: GeckoBoolStructAccessor(self.struct, MCBFEG, SJMCBF, SKSOKP, None),
            CBFEGZ: GeckoBoolStructAccessor(self.struct, CBFEGZ, SJMCBF, KPHUOJ, None),
            BFEGZU: GeckoBoolStructAccessor(self.struct, BFEGZU, SJMCBF, HUOJRJ, None),
            FEGZUQ: GeckoBoolStructAccessor(self.struct, FEGZUQ, SJMCBF, OJRJHI, None),
            EGZUQE: GeckoBoolStructAccessor(self.struct, EGZUQE, SJMCBF, IUSOOQ, None),
            GZUQEX: GeckoBoolStructAccessor(self.struct, GZUQEX, SJMCBF, ZUQEXL, None),
            UQEXLS: GeckoBoolStructAccessor(self.struct, UQEXLS, QEXLSX, BSKSOK, None),
            EXLSXU: GeckoBoolStructAccessor(self.struct, EXLSXU, XLSXUJ, BSKSOK, None),
            LSXUJU: GeckoBoolStructAccessor(self.struct, LSXUJU, XLSXUJ, THECVY, None),
            SXUJUT: GeckoBoolStructAccessor(self.struct, SXUJUT, XLSXUJ, SKSOKP, None),
            XUJUTY: GeckoBoolStructAccessor(self.struct, XUJUTY, XLSXUJ, KPHUOJ, None),
            UJUTYE: GeckoBoolStructAccessor(self.struct, UJUTYE, XLSXUJ, HUOJRJ, None),
            JUTYEK: GeckoBoolStructAccessor(self.struct, JUTYEK, XLSXUJ, OJRJHI, None),
            UTYEKC: GeckoBoolStructAccessor(self.struct, UTYEKC, XLSXUJ, IUSOOQ, None),
            TYEKCW: GeckoBoolStructAccessor(self.struct, TYEKCW, XLSXUJ, ZUQEXL, None),
            YEKCWA: GeckoWordStructAccessor(self.struct, YEKCWA, EKCWAO, None),
            KCWAON: GeckoEnumStructAccessor(
                self.struct, KCWAON, CWAONP, None, YYLIUX, None, None, None
            ),
            YLIUXF: GeckoWordStructAccessor(self.struct, YLIUXF, LIUXFE, None),
            IUXFEF: GeckoByteStructAccessor(self.struct, IUXFEF, UXFEFJ, None),
            XFEFJT: GeckoByteStructAccessor(self.struct, XFEFJT, FEFJTA, None),
            EFJTAC: GeckoTempStructAccessor(self.struct, EFJTAC, FJTACC, None),
            JTACCP: GeckoTempStructAccessor(self.struct, JTACCP, TACCPQ, VHFTHE),
            ACCPQI: GeckoWordStructAccessor(self.struct, ACCPQI, CCPQIP, None),
            CPQIPO: GeckoBoolStructAccessor(self.struct, CPQIPO, PQIPOU, BSKSOK, None),
            QIPOUY: GeckoBoolStructAccessor(self.struct, QIPOUY, PQIPOU, THECVY, None),
            IPOUYN: GeckoBoolStructAccessor(self.struct, IPOUYN, PQIPOU, SKSOKP, None),
            POUYNQ: GeckoBoolStructAccessor(self.struct, POUYNQ, PQIPOU, KPHUOJ, None),
            OUYNQJ: GeckoBoolStructAccessor(self.struct, OUYNQJ, PQIPOU, HUOJRJ, None),
            UYNQJY: GeckoWordStructAccessor(self.struct, UYNQJY, YNQJYM, None),
            NQJYMO: GeckoTempStructAccessor(self.struct, NQJYMO, QJYMOU, None),
            JYMOUN: GeckoWordStructAccessor(self.struct, JYMOUN, YMOUNB, None),
            MOUNBL: GeckoWordStructAccessor(self.struct, MOUNBL, OUNBLK, None),
            UNBLKX: GeckoWordStructAccessor(self.struct, UNBLKX, NBLKXS, None),
            BLKXSJ: GeckoWordStructAccessor(self.struct, BLKXSJ, LKXSJW, None),
            KXSJWM: GeckoByteStructAccessor(self.struct, KXSJWM, XSJWMN, None),
            SJWMNZ: GeckoByteStructAccessor(self.struct, SJWMNZ, JWMNZM, None),
            WMNZMJ: GeckoEnumStructAccessor(
                self.struct, WMNZMJ, MNZMJI, None, YKLGQP, None, None, None
            ),
            KLGQPL: GeckoEnumStructAccessor(
                self.struct, KLGQPL, LGQPLS, BSKSOK, SPFTSI, None, HUOJRJ, None
            ),
            PFTSIF: GeckoWordStructAccessor(self.struct, PFTSIF, FTSIFJ, None),
            TSIFJB: GeckoByteStructAccessor(self.struct, TSIFJB, SIFJBI, None),
            IFJBIA: GeckoByteStructAccessor(self.struct, IFJBIA, FJBIAM, None),
            JBIAMJ: GeckoByteStructAccessor(self.struct, JBIAMJ, BIAMJM, None),
            IAMJMA: GeckoByteStructAccessor(self.struct, IAMJMA, AMJMAO, None),
            MJMAOA: GeckoWordStructAccessor(self.struct, MJMAOA, JMAOAW, None),
            MAOAWB: GeckoByteStructAccessor(self.struct, MAOAWB, AOAWBS, None),
            OAWBSI: GeckoByteStructAccessor(self.struct, OAWBSI, AWBSIR, None),
        }



#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'InYJ v62'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(chr(c) for c in [70, 105, 108, 116, 101, 114])
ACQFFT = 108
AFIKJP = "".join(
    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 52]
)
AHEOCT = 15
AIIDNI = "".join(chr(c) for c in [83, 108, 97, 118, 101, 67, 111, 110, 102, 105, 103])
AKSTSE = "".join(chr(c) for c in [51])
AMJMAO = "".join(chr(c) for c in [68, 117, 97, 108, 80, 97, 99, 107])
AOAWBS = "".join(chr(c) for c in [70, 50])
AONPYY = 58
ASSAKQ = "".join(chr(c) for c in [80, 114, 111, 116, 101, 99, 116, 105, 111, 110])
AWBSIR = "".join(chr(c) for c in [76, 105, 110, 101, 49])
BDJQRJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 67, 104, 97, 110, 103, 101]
)
BFEGZU = "".join(chr(c) for c in [70, 105, 108, 116, 80, 49])
BIAMJM = "".join(chr(c) for c in [73, 110, 112, 117, 116, 77, 101, 110, 117])
BJEUTO = "".join(chr(c) for c in [67, 117, 115, 116, 111, 109, 101, 114, 73, 68])
BLKXSJ = "".join(chr(c) for c in [67])
BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49])
BQFYLJ = 86
BQNRXC = "".join(chr(c) for c in [73, 98, 101, 114, 83, 112, 97])
BQSNQL = "".join(chr(c) for c in [69, 99, 111, 110, 68, 117, 114])
BSKSOK = "".join(chr(c) for c in [79, 117, 116, 76, 105])
BSSUHB = "".join(
    chr(c) for c in [72, 105, 103, 104, 83, 112, 101, 101, 100, 79, 110, 108, 121]
)
BVWVUB = "".join(chr(c) for c in [70, 114, 101, 101, 80, 117, 109, 112, 75, 101, 121])
BWJYKL = 68
BXIBHZ = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 52]
)
BXTIAC = "".join(chr(c) for c in [83, 76, 69, 69, 80])
BXYBQS = 23
BYGDSB = "".join(
    chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 111, 102, 116, 83, 116, 111, 112]
)
CBFEGZ = "".join(chr(c) for c in [70, 105, 108, 116, 67, 80])
CCPQIP = "".join(chr(c) for c in [65, 108, 119, 97, 121, 115])
CGETIX = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 52]
)
CHWDAF = "".join(
    chr(c) for c in [72, 73, 68, 69, 95, 68, 69, 84, 65, 73, 76, 69, 68, 95, 77, 83, 71]
)
CQBMJV = 0
CQFFTT = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
CRTFMN = "".join(chr(c) for c in [67, 89, 65, 78])
CTHBSK = "".join(
    chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108, 65, 115, 67, 80]
)
CVYYPI = "".join(chr(c) for c in [80, 52, 72])
CWAONP = 1
CXQIEF = 16
DAFIKJ = "".join(
    chr(c)
    for c in [
        76,
        111,
        119,
        101,
        114,
        83,
        101,
        116,
        112,
        111,
        105,
        110,
        116,
        77,
        101,
        110,
        117,
    ]
)
DGKEAK = 127
DJQRJJ = "".join(
    chr(c) for c in [78, 79, 95, 82, 69, 83, 84, 82, 73, 67, 84, 73, 79, 78]
)
DNIBXT = 107
DNQGVU = "".join(chr(c) for c in [74, 97, 122, 122, 105])
DQLAII = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114])
DSBDJQ = 43
DUBSSU = "".join(
    chr(c)
    for c in [80, 117, 109, 112, 49, 85, 115, 101, 114, 65, 99, 99, 101, 115, 115]
)
DZXNQT = 124
EAKSTS = "".join(chr(c) for c in [50])
ECVYYP = "".join(chr(c) for c in [80, 51, 76])
EFJTAC = "".join(chr(c) for c in [80, 49])
EFXQGL = "".join(chr(c) for c in [79, 117, 116, 50, 67, 117, 114])
EJNIBX = 4
EKVKZI = "".join(
    chr(c)
    for c in [83, 111, 97, 107, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
ELHBQN = "".join(chr(c) for c in [65, 115, 112, 101, 110])
EMCGET = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 50]
)
EOCTHB = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 67, 117, 114])
ETIXQV = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 50]
)
EUTOPH = "".join(chr(c) for c in [71, 101, 110, 101, 114, 105, 99])
FCRTFM = "".join(chr(c) for c in [77, 65, 71, 69, 78, 84, 65])
FEFJTA = 78
FEGZUQ = "".join(
    chr(c) for c in [70, 105, 108, 116, 80, 49, 68, 117, 114, 79, 110, 108, 121]
)
FFTTID = "".join(chr(c) for c in [65, 109, 80, 109])
FIKJPU = 46
FJBIAM = "".join(
    chr(c) for c in [73, 110, 112, 117, 116, 67, 117, 114, 114, 101, 110, 116]
)
FMNHTB = 8
FTHECV = "".join(chr(c) for c in [80, 50, 72])
FTSIFJ = "".join(chr(c) for c in [67, 69])
FTTIDU = "".join(chr(c) for c in [50, 52, 104])
FXQGLR = 37
FYLJUI = 87
FZDGKE = "".join(chr(c) for c in [90, 111, 110, 101, 52, 84, 121, 112, 101])
GDSBDJ = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        84,
        104,
        101,
        114,
        97,
        112,
        121,
        83,
        117,
        112,
        112,
        111,
        114,
        116,
    ]
)
GETIXQ = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 49]
)
GKEAKS = "".join(chr(c) for c in [78, 111, 110, 101])
GLRAHE = "".join(chr(c) for c in [79, 117, 116, 72, 116, 82, 67, 117, 114])
GQPLSP = 77
GSELHB = "".join(chr(c) for c in [68, 101, 108, 117, 120, 101])
GTYIYW = "".join(chr(c) for c in [66, 97, 114, 101, 102, 111, 111, 116])
GVUNXN = "".join(chr(c) for c in [77, 65, 65, 88])
GYOUSP = 3
GZUQEX = "".join(chr(c) for c in [67, 112, 85, 115, 97, 103, 101])
HBQNRX = "".join(chr(c) for c in [84, 105, 116, 97, 110, 95, 83, 112, 97, 115])
HBSKSO = 2
HBVWVU = "".join(
    chr(c)
    for c in [66, 108, 111, 119, 101, 114, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
HBXIBH = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 51]
)
HECVYY = "".join(chr(c) for c in [80, 51, 72])
HFTHEC = "".join(chr(c) for c in [80, 49, 76])
HIUSOO = 81
HTBJEU = "".join(chr(c) for c in [69, 110, 97, 98, 108, 101])
HUGTYI = "".join(chr(c) for c in [65, 114, 116, 101, 115, 105, 97, 110])
HUOJRJ = 54
HWDAFI = "".join(chr(c) for c in [83, 72, 79, 87, 95, 65, 76, 76, 95, 77, 83, 71])
HXEKVK = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        67,
        111,
        110,
        116,
        114,
        111,
        108,
        97,
        98,
        108,
        101,
        77,
        97,
        110,
        117,
        97,
        108,
        108,
        121,
    ]
)
HZVOAC = 62
IACQFF = "".join(
    chr(c) for c in [83, 105, 108, 101, 110, 116, 68, 117, 114, 97, 116, 105, 111, 110]
)
IAMJMA = 74
IBXTIA = "".join(chr(c) for c in [69, 67, 79, 78, 79, 77, 89])
IBXYBQ = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114, 50])
ICXQIE = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114])
IDNIBX = "".join(chr(c) for c in [83, 105, 108, 101, 110, 116, 77, 111, 100, 101])
IDUBSS = 64
IEFXQG = 36
IFJBIA = 52
IHBXIB = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 50]
)
IIDNIB = 75
IJUGSE = "".join(
    chr(c) for c in [87, 87, 79, 95, 87, 104, 105, 114, 108, 99, 97, 114, 101]
)
IKFWRK = "".join(chr(c) for c in [70, 50, 76, 105, 110, 101])
IKJPUN = "".join(
    chr(c)
    for c in [
        68,
        101,
        97,
        108,
        101,
        114,
        76,
        111,
        99,
        107,
        83,
        117,
        112,
        112,
        111,
        114,
        116,
    ]
)
ILXWAJ = "".join(
    chr(c) for c in [77, 117, 108, 116, 105, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
INEJNI = 3
IPIVLA = "".join(chr(c) for c in [79, 51])
IRYXBQ = 84
IUSOOQ = "".join(chr(c) for c in [83, 104, 97, 114, 101, 100])
IUXFEF = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
IVDNQG = "".join(chr(c) for c in [72, 111, 116, 115, 112, 114, 105, 110, 103])
IVLASS = "".join(chr(c) for c in [72, 84, 82])
IXQVXO = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 52]
)
IYWSKW = "".join(
    chr(c)
    for c in [76, 101, 105, 115, 117, 114, 101, 95, 80, 114, 111, 100, 95, 73, 110, 100]
)
JBIAMJ = 53
JEUTOP = 44
JHIUSO = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 114])
JIGYOU = "".join(chr(c) for c in [73, 110, 116, 111, 84, 117, 98])
JJJVYF = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        66,
        97,
        99,
        107,
        108,
        105,
        103,
        104,
        116,
        67,
        111,
        108,
        111,
        114,
    ]
)
JJVYFC = "".join(chr(c) for c in [82, 69, 68])
JMAOAW = "".join(chr(c) for c in [79, 117, 116, 49, 70, 117, 115, 101])
JMCBFE = 32
JNIBXY = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114])
JPUNRJ = 121
JQRJJJ = "".join(
    chr(c)
    for c in [80, 65, 83, 83, 87, 79, 82, 68, 95, 80, 82, 79, 84, 69, 67, 84, 69, 68]
)
JRJHIU = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 79, 117, 116])
JTACCP = "".join(chr(c) for c in [79, 51, 85, 115, 97, 103, 101])
JUGSEL = "".join(chr(c) for c in [79, 107, 101, 97, 110, 111, 115])
JUIKFW = "".join(chr(c) for c in [70, 52, 67, 117, 114, 114, 101, 110, 116])
JVDQLA = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 83, 108, 97, 118, 101])
JVHFTH = "".join(chr(c) for c in [78, 65])
JVYFCR = "".join(chr(c) for c in [71, 82, 69, 69, 78])
JWMNZM = 25
JYKLGQ = 70
JYMOUN = 63
JZTATD = "".join(chr(c) for c in [90, 111, 110, 101, 49, 84, 121, 112, 101])
KCWAON = "".join(
    chr(c) for c in [65, 117, 120, 65, 115, 66, 117, 98, 98, 108, 101, 71, 101, 110]
)
KEAKST = "".join(chr(c) for c in [49])
KFWRKI = 104
KINEJN = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
KJPUNR = "".join(chr(c) for c in [76, 111, 99, 107, 69, 110, 97, 98, 108, 101, 100])
KMLOIJ = "".join(chr(c) for c in [83, 117, 110, 114, 105, 115, 101])
KPHUOJ = 80
KQXPIC = "".join(chr(c) for c in [79, 117, 116, 50])
KSOKPH = "".join(chr(c) for c in [76, 73])
KSTSEM = "".join(chr(c) for c in [52])
KVKZIL = "".join(
    chr(c) for c in [79, 102, 102, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
KWIVDN = "".join(chr(c) for c in [68, 121, 110, 97, 115, 116, 121])
KXSJWM = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
KZILXW = "".join(
    chr(c)
    for c in [
        81,
        117,
        105,
        99,
        107,
        79,
        110,
        79,
        102,
        102,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
LASSAK = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
LGQPLS = "".join(
    chr(c) for c in [78, 111, 72, 101, 97, 116, 80, 101, 114, 105, 111, 100]
)
LHBQNR = "".join(chr(c) for c in [84, 104, 101, 114, 109, 111, 83, 112, 97, 115])
LIUXFE = 61
LJUIKF = 98
LOIJUG = "".join(
    chr(c) for c in [83, 112, 97, 95, 73, 110, 100, 117, 115, 116, 114, 105, 101, 115]
)
LRAHEO = 40
LSPFTS = "".join(chr(c) for c in [85, 76, 95, 67, 69])
LSXUJU = 57
LXWAJV = 76
MAOAWB = 83
MCBFEG = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
MCGETI = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 51]
)
MFZDGK = 126
MHXEKV = 82
MJIGYO = "".join(chr(c) for c in [73, 110, 116, 111, 80, 105, 112, 105, 110, 103])
MJVHFT = 12
MLOIJU = "".join(
    chr(c) for c in [83, 117, 112, 101, 114, 105, 111, 114, 83, 112, 97, 115]
)
MNHTBJ = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        66,
        97,
        99,
        107,
        108,
        105,
        103,
        104,
        116,
        69,
        100,
        105,
        116,
    ]
)
MNZMJI = "".join(
    chr(c) for c in [78, 111, 116, 73, 110, 115, 116, 97, 108, 108, 101, 100]
)
MOUNBL = 1
NBLKXS = "".join(chr(c) for c in [70])
NEJNIB = "".join(chr(c) for c in [70, 105, 108, 116, 83, 116, 97, 114, 116])
NHTBJE = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101])
NIBXTI = "".join(chr(c) for c in [79, 70, 70])
NIBXYB = 6
NKMLOI = "".join(chr(c) for c in [83, 117, 110, 114, 97, 110, 115])
NMHXEK = "".join(chr(c) for c in [85, 68, 80, 114, 111, 103, 69, 99, 111, 110])
NPYYLI = 59
NQGVUN = "".join(chr(c) for c in [76, 65])
NQLNMH = 71
NQTMFZ = 125
NRJZTA = "".join(chr(c) for c in [82, 71, 66])
NRSJMC = "".join(
    chr(c)
    for c in [87, 97, 116, 101, 114, 102, 97, 108, 108, 84, 105, 109, 101, 79, 117, 116]
)
NRXCHW = "".join(
    chr(c)
    for c in [
        77,
        111,
        100,
        101,
        75,
        101,
        121,
        65,
        115,
        73,
        110,
        118,
        101,
        114,
        116,
        68,
        105,
        115,
        112,
        108,
        97,
        121,
        75,
        101,
        121,
    ]
)
NXNKML = "".join(
    chr(c)
    for c in [80, 114, 101, 109, 105, 117, 109, 95, 76, 101, 105, 115, 117, 114, 101]
)
OAWBSI = "".join(chr(c) for c in [70, 52])
OCTHBS = 39
OIHBXI = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 52, 84, 111, 79, 117, 116, 49]
)
OIJUGS = "".join(chr(c) for c in [86, 105, 107, 105, 110, 103])
OJRJHI = 55
OKPHUO = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
ONPYYL = "".join(
    chr(c)
    for c in [67, 112, 79, 110, 84, 105, 109, 101, 68, 117, 114, 105, 110, 103, 79, 84]
)
OOQNRS = 0
OPHUGT = "".join(chr(c) for c in [87, 101, 108, 108, 105, 115])
OQNRSJ = "".join(chr(c) for c in [65, 117, 120, 84, 105, 109, 101, 79, 117, 116])
OUNBLK = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
OUSPBW = 35
OUYNQJ = 30
PBWJYK = "".join(
    chr(c) for c in [77, 97, 120, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
PFTSIF = "".join(chr(c) for c in [85, 76])
PHUGTY = "".join(chr(c) for c in [65, 108, 112, 115])
PHUOJR = "".join(chr(c) for c in [80, 117, 109, 112, 84, 105, 109, 101, 79, 117, 116])
PICXQI = 14
PIPIVL = "".join(chr(c) for c in [67, 80])
PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
PLSPFT = 26
POUYNQ = "".join(chr(c) for c in [79, 51, 84, 121, 112, 101])
PQIPOU = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
PUNRJZ = "".join(chr(c) for c in [90, 111, 110, 101, 49, 76, 101, 100])
PYYLIU = "".join(
    chr(c)
    for c in [
        67,
        112,
        79,
        102,
        102,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QEXLSX = "".join(chr(c) for c in [65, 76, 87, 65, 89, 83, 95, 79, 78])
QFFTTI = 34
QFYLJU = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114, 70, 117, 115, 101])
QGLRAH = 38
QGVUNX = "".join(chr(c) for c in [80, 114, 111, 95, 70, 108, 111, 97, 116])
QIEFXQ = "".join(chr(c) for c in [79, 117, 116, 49, 67, 117, 114])
QIPOUY = 29
QJYMOU = "".join(
    chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
QLAIID = "".join(chr(c) for c in [83, 108, 97, 118, 101])
QLNMHX = "".join(
    chr(c) for c in [79, 85, 84, 83, 73, 68, 69, 95, 70, 73, 76, 84, 69, 82]
)
QNRSJM = 48
QPLSPF = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        78,
        117,
        109,
        98,
        101,
        114,
        79,
        102,
        80,
        104,
        97,
        115,
        101,
        115,
    ]
)
QSNQLN = 10
QTMFZD = "".join(chr(c) for c in [90, 111, 110, 101, 51, 84, 121, 112, 101])
QVXOIH = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 50]
)
QXPICX = 13
RAHEOC = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116])
RJHIUS = 56
RJJJVY = "".join(
    chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 67, 104, 97, 110, 103, 101]
)
RKINEJ = 105
RSJMCB = 118
RTFMNH = "".join(chr(c) for c in [87, 72, 73, 84, 69])
RXCHWD = 45
RYXBQF = "".join(chr(c) for c in [79, 117, 116, 51, 70, 117, 115, 101])
SAKQXP = "".join(chr(c) for c in [65, 85, 88])
SBDJQR = "".join(
    chr(c)
    for c in [67, 117, 115, 116, 111, 109, 75, 101, 121, 69, 110, 97, 98, 108, 101, 100]
)
SELHBQ = "".join(chr(c) for c in [73, 100, 111, 108])
SEMCGE = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 49, 84, 111, 79, 117, 116, 49]
)
SIFJBI = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
SIRYXB = "".join(chr(c) for c in [79, 117, 116, 50, 70, 117, 115, 101])
SJMCBF = "".join(
    chr(c) for c in [70, 105, 108, 116, 73, 110, 116, 101, 114, 102, 97, 99, 101]
)
SJWMNZ = "".join(
    chr(c) for c in [70, 108, 111, 119, 68, 101, 116, 101, 99, 116, 111, 114]
)
SKSOKP = 79
SKWIVD = "".join(
    chr(c) for c in [68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 111, 110, 101]
)
SNQLNM = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        80,
        114,
        111,
        103,
        65,
        118,
        97,
        105,
        108,
        97,
        98,
        108,
        101,
    ]
)
SPBWJY = 66
SPFTSI = 51
SSAKQX = "".join(chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108])
SUHBVW = "".join(
    chr(c) for c in [83, 101, 108, 102, 67, 108, 101, 97, 110, 77, 115, 103]
)
SXUJUT = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101, 100])
TACCPQ = 28
TATDZX = "".join(chr(c) for c in [83, 84, 65, 84, 85, 83])
TDZXNQ = "".join(chr(c) for c in [90, 111, 110, 101, 50, 76, 101, 100])
THBSKS = 47
THECVY = "".join(chr(c) for c in [80, 50, 76])
TIDUBS = "".join(
    chr(c)
    for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 84, 114, 105, 103, 65, 68, 67]
)
TIXQVX = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 50, 84, 111, 79, 117, 116, 51]
)
TMFZDG = "".join(chr(c) for c in [90, 111, 110, 101, 52, 76, 101, 100])
TOPHUG = "".join(
    chr(c) for c in [69, 110, 100, 108, 101, 115, 115, 80, 111, 111, 108, 115]
)
TSEMCG = "".join(
    chr(c) for c in [77, 97, 112, 112, 105, 110, 103, 69, 110, 97, 98, 108, 101]
)
TYEKCW = "".join(chr(c) for c in [76, 111])
TYIYWS = "".join(chr(c) for c in [66, 101, 97, 99, 104, 99, 111, 109, 98, 101, 114])
UBSSUH = "".join(chr(c) for c in [66, 111, 116, 104, 83, 112, 101, 101, 100, 115])
UBYGDS = 6
UGSELH = "".join(chr(c) for c in [67, 108, 101, 97, 114, 119, 97, 116, 101, 114])
UGTYIY = "".join(chr(c) for c in [65, 114, 99, 116, 105, 99])
UHBVWV = 4
UIKFWR = 99
UJUTYE = "".join(
    chr(c) for c in [87, 105, 116, 104, 83, 80, 79, 118, 101, 114, 57, 53, 70]
)
UNBLKX = 33
UNRJZT = 123
UNXNKM = "".join(chr(c) for c in [80, 68, 67])
UOJRJH = "".join(
    chr(c) for c in [76, 105, 103, 104, 116, 84, 105, 109, 101, 79, 117, 116]
)
UQEXLS = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
USOOQN = "".join(chr(c) for c in [79, 119, 110])
USPBWJ = "".join(
    chr(c) for c in [77, 105, 110, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
UTOPHU = "".join(chr(c) for c in [72, 121, 100, 114, 111, 112, 111, 111, 108])
UTYEKC = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 112, 101, 101, 100])
UXFEFJ = 62
UYNQJY = "".join(chr(c) for c in [83, 116, 97, 110, 100, 97, 114, 100])
VDNQGV = "".join(chr(c) for c in [74, 97, 99, 117, 122, 122, 105])
VDQLAI = 73
VHFTHE = "".join(chr(c) for c in [80, 49, 72])
VKZILX = "".join(
    chr(c)
    for c in [
        67,
        108,
        101,
        97,
        110,
        117,
        112,
        79,
        110,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
VLASSA = "".join(chr(c) for c in [])
VUBYGD = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 101, 114, 83, 111, 102, 116, 83, 116, 97, 114, 116]
)
VUNXNK = "".join(chr(c) for c in [77, 97, 114, 113, 117, 105, 115])
VWVUBY = "".join(chr(c) for c in [76, 97, 115, 116, 80, 117, 109, 112, 75, 101, 121])
VXOIHB = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 51]
)
VYFCRT = "".join(chr(c) for c in [89, 69, 76, 76, 79, 87])
VYYPIP = "".join(chr(c) for c in [80, 52, 76])
WAJVDQ = "".join(chr(c) for c in [66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67])
WAONPY = "".join(chr(c) for c in [79, 84, 84, 114, 105, 103, 103, 101, 114, 71])
WBSIRY = "".join(chr(c) for c in [76, 105, 110, 101, 50])
WIVDNQ = "".join(chr(c) for c in [70, 111, 117, 114, 95, 87, 105, 110, 100])
WJYKLG = "".join(chr(c) for c in [69, 99, 111, 110, 84, 121, 112, 101])
WMNZMJ = "".join(chr(c) for c in [105, 110, 70, 108, 111])
WRKINE = "".join(chr(c) for c in [70, 52, 76, 105, 110, 101])
WSKWIV = "".join(chr(c) for c in [67, 111, 97, 115, 116])
XBQFYL = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 49, 70, 117, 115, 101])
XCHWDA = "".join(
    chr(c) for c in [73, 110, 102, 111, 77, 115, 103, 67, 111, 110, 102, 105, 103]
)
XEKVKZ = 72
XFEFJT = "".join(chr(c) for c in [68, 114, 97, 105, 110, 77, 111, 100, 101])
XLSXUJ = "".join(chr(c) for c in [79, 116, 79, 112, 116, 105, 111, 110])
XNKMLO = "".join(chr(c) for c in [83, 116, 114, 111, 110, 103])
XNQTMF = "".join(chr(c) for c in [90, 111, 110, 101, 51, 76, 101, 100])
XOIHBX = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 52]
)
XPICXQ = "".join(chr(c) for c in [79, 117, 116, 51])
XQGLRA = "".join(chr(c) for c in [79, 117, 116, 51, 67, 117, 114])
XQVXOI = "".join(
    chr(c) for c in [77, 97, 112, 90, 111, 110, 101, 51, 84, 111, 79, 117, 116, 49]
)
XSJWMN = 31
XTIACQ = "".join(chr(c) for c in [78, 73, 71, 72, 84])
XUJUTY = "".join(
    chr(c) for c in [65, 108, 119, 97, 121, 115, 69, 110, 97, 98, 108, 101, 100]
)
XWAJVD = "".join(
    chr(c) for c in [78, 111, 66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67]
)
XYBQSN = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 97, 114, 116])
YBQSNQ = 8
YEKCWA = "".join(chr(c) for c in [72, 105])
YFCRTF = "".join(chr(c) for c in [66, 76, 85, 69])
YGDSBD = 7
YIYWSK = "".join(chr(c) for c in [66, 101, 108, 108, 97, 103, 105, 111])
YKLGQP = "".join(chr(c) for c in [78, 105, 103, 104, 116])
YLIUXF = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        79,
        110,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
YLJUIK = "".join(chr(c) for c in [70, 50, 67, 117, 114, 114, 101, 110, 116])
YMOUNB = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
YNQJYM = "".join(chr(c) for c in [84, 111, 103, 103, 108, 101])
YOUSPB = "".join(
    chr(c) for c in [67, 111, 111, 108, 100, 111, 119, 110, 84, 105, 109, 101]
)
YPIPIV = "".join(chr(c) for c in [66, 76, 79])
YWSKWI = "".join(chr(c) for c in [66, 117, 108, 108, 102, 114, 111, 103])
YXBQFY = 85
YYLIUX = 60
YYPIPI = "".join(chr(c) for c in [80, 53])
ZCQBMJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
)
ZDGKEA = "".join(
    chr(c) for c in [78, 117, 109, 98, 101, 114, 79, 102, 90, 111, 110, 101, 115]
)
ZILXWA = 5
ZMJIGY = "".join(
    chr(c) for c in [80, 114, 111, 98, 101, 76, 111, 99, 97, 116, 105, 111, 110]
)
ZTATDZ = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
ZUQEXL = 27
ZXNQTM = "".join(chr(c) for c in [90, 111, 110, 101, 50, 84, 121, 112, 101])
AJVDQL = [XWAJVD, WAJVDQ]
AKQXPI = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    LASSAK,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    ASSAKQ,
    VLASSA,
    SSAKQX,
    SAKQXP,
]
ATDZXN = [ZTATDZ, TATDZX]
BHZVOA = []
BSIRYX = [AOAWBS, OAWBSI, VLASSA, VLASSA, VLASSA, VLASSA, AWBSIR, WBSIRY]
CPQIPO = [ACCPQI, CCPQIP]
EGZUQE = [MCBFEG, CBFEGZ, BFEGZU, FEGZUQ]
EKCWAO = [TYEKCW, YEKCWA]
EXLSXU = [UQEXLS, QEXLSX]
FJTACC = [JVHFTH, EFJTAC, PIPIVL]
FWRKIN = [VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, AWBSIR, WBSIRY]
HEOCTH = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    PIPIVL,
]
IBHZVO = [KSOKPH]
IGYOUS = [MJIGYO, JIGYOU]
IPOUYN = [PIPIVL, EFJTAC]
JUTYEK = [SXUJUT, XUJUTY, UJUTYE]
KLGQPL = [UYNQJY, YKLGQP]
LAIIDN = [VLASSA, DQLAII, QLAIID]
LKXSJW = [NBLKXS, BLKXSJ]
LNMHXE = [JVHFTH, UQEXLS, QLNMHX]
MJMAOA = [UYNQJY, AMJMAO]
NQJYMO = [UYNQJY, YNQJYM]
NZMJIG = [WMNZMJ, MNZMJI]
QNRXCH = [
    EUTOPH,
    UTOPHU,
    TOPHUG,
    OPHUGT,
    PHUGTY,
    HUGTYI,
    UGTYIY,
    GTYIYW,
    TYIYWS,
    YIYWSK,
    IYWSKW,
    YWSKWI,
    WSKWIV,
    SKWIVD,
    KWIVDN,
    WIVDNQ,
    IVDNQG,
    VDNQGV,
    DNQGVU,
    NQGVUN,
    QGVUNX,
    GVUNXN,
    VUNXNK,
    UNXNKM,
    NXNKML,
    XNKMLO,
    NKMLOI,
    KMLOIJ,
    MLOIJU,
    LOIJUG,
    OIJUGS,
    IJUGSE,
    JUGSEL,
    UGSELH,
    GSELHB,
    SELHBQ,
    ELHBQN,
    LHBQNR,
    HBQNRX,
    BQNRXC,
]
QRJJJV = [DJQRJJ, JQRJJJ]
RJZTAT = [NRJZTA, RTFMNH]
SOKPHU = [
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    KSOKPH,
]
SOOQNR = [IUSOOQ, USOOQN]
SSUHBV = [UBSSUH, BSSUHB]
STSEMC = [GKEAKS, KEAKST, EAKSTS, AKSTSE, KSTSEM]
TBJEUT = [NHTBJE, HTBJEU]
TFMNHT = [NIBXTI, JJVYFC, JVYFCR, VYFCRT, YFCRTF, FCRTFM, CRTFMN, RTFMNH]
TIACQF = [JVHFTH, NIBXTI, IBXTIA, BXTIAC, XTIACQ]
TSIFJB = [PFTSIF, FTSIFJ]
TTIDUB = [JVHFTH, FFTTID, FTTIDU]
WDAFIK = [CHWDAF, HWDAFI, VLASSA, VLASSA]
WVUBYG = [BVWVUB, VWVUBY]
XIBHZV = [BMJVHF, KQXPIC, XPICXQ, ICXQIE, RAHEOC, BSKSOK]
XQIEFX = [
    JVHFTH,
    VHFTHE,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    IVLASS,
]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return HZVOAC

    @property
    def output_keys(self):
        return XIBHZV

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, AKQXPI, None, None, QBMJVH
            ),
            KQXPIC: GeckoEnumStructAccessor(
                self.struct, KQXPIC, QXPICX, None, AKQXPI, None, None, QBMJVH
            ),
            XPICXQ: GeckoEnumStructAccessor(
                self.struct, XPICXQ, PICXQI, None, AKQXPI, None, None, QBMJVH
            ),
            ICXQIE: GeckoEnumStructAccessor(
                self.struct, ICXQIE, CXQIEF, None, XQIEFX, None, None, QBMJVH
            ),
            QIEFXQ: GeckoByteStructAccessor(self.struct, QIEFXQ, IEFXQG, QBMJVH),
            EFXQGL: GeckoByteStructAccessor(self.struct, EFXQGL, FXQGLR, QBMJVH),
            XQGLRA: GeckoByteStructAccessor(self.struct, XQGLRA, QGLRAH, QBMJVH),
            GLRAHE: GeckoByteStructAccessor(self.struct, GLRAHE, LRAHEO, QBMJVH),
            RAHEOC: GeckoEnumStructAccessor(
                self.struct, RAHEOC, AHEOCT, None, HEOCTH, None, None, QBMJVH
            ),
            EOCTHB: GeckoByteStructAccessor(self.struct, EOCTHB, OCTHBS, QBMJVH),
            CTHBSK: GeckoBoolStructAccessor(
                self.struct, CTHBSK, THBSKS, HBSKSO, QBMJVH
            ),
            BSKSOK: GeckoEnumStructAccessor(
                self.struct, BSKSOK, SKSOKP, None, SOKPHU, None, None, None
            ),
            OKPHUO: GeckoByteStructAccessor(self.struct, OKPHUO, KPHUOJ, None),
            PHUOJR: GeckoByteStructAccessor(self.struct, PHUOJR, HUOJRJ, QBMJVH),
            UOJRJH: GeckoByteStructAccessor(self.struct, UOJRJH, OJRJHI, QBMJVH),
            JRJHIU: GeckoByteStructAccessor(self.struct, JRJHIU, RJHIUS, QBMJVH),
            JHIUSO: GeckoEnumStructAccessor(
                self.struct, JHIUSO, HIUSOO, OOQNRS, SOOQNR, None, HBSKSO, QBMJVH
            ),
            OQNRSJ: GeckoByteStructAccessor(self.struct, OQNRSJ, QNRSJM, QBMJVH),
            NRSJMC: GeckoByteStructAccessor(self.struct, NRSJMC, RSJMCB, QBMJVH),
            SJMCBF: GeckoEnumStructAccessor(
                self.struct, SJMCBF, JMCBFE, None, EGZUQE, None, None, QBMJVH
            ),
            GZUQEX: GeckoEnumStructAccessor(
                self.struct, GZUQEX, ZUQEXL, None, EXLSXU, None, None, QBMJVH
            ),
            XLSXUJ: GeckoEnumStructAccessor(
                self.struct, XLSXUJ, LSXUJU, None, JUTYEK, None, None, QBMJVH
            ),
            UTYEKC: GeckoEnumStructAccessor(
                self.struct, UTYEKC, HIUSOO, HBSKSO, EKCWAO, None, HBSKSO, QBMJVH
            ),
            KCWAON: GeckoBoolStructAccessor(
                self.struct, KCWAON, THBSKS, CWAONP, QBMJVH
            ),
            WAONPY: GeckoByteStructAccessor(self.struct, WAONPY, AONPYY, QBMJVH),
            ONPYYL: GeckoByteStructAccessor(self.struct, ONPYYL, NPYYLI, QBMJVH),
            PYYLIU: GeckoByteStructAccessor(self.struct, PYYLIU, YYLIUX, QBMJVH),
            YLIUXF: GeckoByteStructAccessor(self.struct, YLIUXF, LIUXFE, QBMJVH),
            IUXFEF: GeckoByteStructAccessor(self.struct, IUXFEF, UXFEFJ, QBMJVH),
            XFEFJT: GeckoEnumStructAccessor(
                self.struct, XFEFJT, FEFJTA, None, FJTACC, None, None, QBMJVH
            ),
            JTACCP: GeckoEnumStructAccessor(
                self.struct, JTACCP, TACCPQ, None, CPQIPO, None, None, QBMJVH
            ),
            PQIPOU: GeckoEnumStructAccessor(
                self.struct, PQIPOU, QIPOUY, None, IPOUYN, None, None, QBMJVH
            ),
            POUYNQ: GeckoEnumStructAccessor(
                self.struct, POUYNQ, OUYNQJ, None, NQJYMO, None, None, QBMJVH
            ),
            QJYMOU: GeckoByteStructAccessor(self.struct, QJYMOU, JYMOUN, QBMJVH),
            YMOUNB: GeckoTempStructAccessor(self.struct, YMOUNB, MOUNBL, QBMJVH),
            OUNBLK: GeckoEnumStructAccessor(
                self.struct, OUNBLK, UNBLKX, None, LKXSJW, None, None, QBMJVH
            ),
            KXSJWM: GeckoEnumStructAccessor(
                self.struct, KXSJWM, XSJWMN, None, IPOUYN, None, None, QBMJVH
            ),
            SJWMNZ: GeckoEnumStructAccessor(
                self.struct, SJWMNZ, JWMNZM, None, NZMJIG, None, None, QBMJVH
            ),
            ZMJIGY: GeckoEnumStructAccessor(
                self.struct, ZMJIGY, HIUSOO, GYOUSP, IGYOUS, None, HBSKSO, QBMJVH
            ),
            YOUSPB: GeckoByteStructAccessor(self.struct, YOUSPB, OUSPBW, QBMJVH),
            USPBWJ: GeckoTempStructAccessor(self.struct, USPBWJ, SPBWJY, QBMJVH),
            PBWJYK: GeckoTempStructAccessor(self.struct, PBWJYK, BWJYKL, QBMJVH),
            WJYKLG: GeckoEnumStructAccessor(
                self.struct, WJYKLG, JYKLGQ, None, KLGQPL, None, None, QBMJVH
            ),
            LGQPLS: GeckoByteStructAccessor(self.struct, LGQPLS, GQPLSP, QBMJVH),
            QPLSPF: GeckoByteStructAccessor(self.struct, QPLSPF, PLSPFT, QBMJVH),
            LSPFTS: GeckoEnumStructAccessor(
                self.struct, LSPFTS, SPFTSI, None, TSIFJB, None, None, QBMJVH
            ),
            SIFJBI: GeckoByteStructAccessor(self.struct, SIFJBI, IFJBIA, QBMJVH),
            FJBIAM: GeckoByteStructAccessor(self.struct, FJBIAM, JBIAMJ, QBMJVH),
            BIAMJM: GeckoEnumStructAccessor(
                self.struct, BIAMJM, IAMJMA, None, MJMAOA, None, None, QBMJVH
            ),
            JMAOAW: GeckoEnumStructAccessor(
                self.struct, JMAOAW, MAOAWB, None, BSIRYX, None, None, QBMJVH
            ),
            SIRYXB: GeckoEnumStructAccessor(
                self.struct, SIRYXB, IRYXBQ, None, BSIRYX, None, None, QBMJVH
            ),
            RYXBQF: GeckoEnumStructAccessor(
                self.struct, RYXBQF, YXBQFY, None, BSIRYX, None, None, QBMJVH
            ),
            XBQFYL: GeckoEnumStructAccessor(
                self.struct, XBQFYL, BQFYLJ, None, BSIRYX, None, None, QBMJVH
            ),
            QFYLJU: GeckoEnumStructAccessor(
                self.struct, QFYLJU, FYLJUI, None, BSIRYX, None, None, QBMJVH
            ),
            YLJUIK: GeckoByteStructAccessor(self.struct, YLJUIK, LJUIKF, QBMJVH),
            JUIKFW: GeckoByteStructAccessor(self.struct, JUIKFW, UIKFWR, QBMJVH),
            IKFWRK: GeckoEnumStructAccessor(
                self.struct, IKFWRK, KFWRKI, None, FWRKIN, None, None, QBMJVH
            ),
            WRKINE: GeckoEnumStructAccessor(
                self.struct, WRKINE, RKINEJ, None, FWRKIN, None, None, QBMJVH
            ),
            KINEJN: GeckoByteStructAccessor(self.struct, KINEJN, INEJNI, QBMJVH),
            NEJNIB: GeckoTimeStructAccessor(self.struct, NEJNIB, EJNIBX, QBMJVH),
            JNIBXY: GeckoTimeStructAccessor(self.struct, JNIBXY, NIBXYB, QBMJVH),
            IBXYBQ: GeckoTimeStructAccessor(self.struct, IBXYBQ, BXYBQS, QBMJVH),
            XYBQSN: GeckoTimeStructAccessor(self.struct, XYBQSN, YBQSNQ, QBMJVH),
            BQSNQL: GeckoTimeStructAccessor(self.struct, BQSNQL, QSNQLN, QBMJVH),
            SNQLNM: GeckoEnumStructAccessor(
                self.struct, SNQLNM, NQLNMH, None, LNMHXE, None, None, QBMJVH
            ),
            NMHXEK: GeckoBoolStructAccessor(
                self.struct, NMHXEK, MHXEKV, OOQNRS, QBMJVH
            ),
            HXEKVK: GeckoBoolStructAccessor(
                self.struct, HXEKVK, XEKVKZ, HBSKSO, QBMJVH
            ),
            EKVKZI: GeckoBoolStructAccessor(
                self.struct, EKVKZI, XEKVKZ, OOQNRS, QBMJVH
            ),
            KVKZIL: GeckoBoolStructAccessor(
                self.struct, KVKZIL, XEKVKZ, CWAONP, QBMJVH
            ),
            VKZILX: GeckoBoolStructAccessor(
                self.struct, VKZILX, XEKVKZ, GYOUSP, QBMJVH
            ),
            KZILXW: GeckoBoolStructAccessor(
                self.struct, KZILXW, XEKVKZ, ZILXWA, QBMJVH
            ),
            ILXWAJ: GeckoEnumStructAccessor(
                self.struct, ILXWAJ, LXWAJV, None, AJVDQL, None, None, QBMJVH
            ),
            JVDQLA: GeckoEnumStructAccessor(
                self.struct, JVDQLA, VDQLAI, None, LAIIDN, None, None, QBMJVH
            ),
            AIIDNI: GeckoByteStructAccessor(self.struct, AIIDNI, IIDNIB, QBMJVH),
            IDNIBX: GeckoEnumStructAccessor(
                self.struct, IDNIBX, DNIBXT, None, TIACQF, None, None, QBMJVH
            ),
            IACQFF: GeckoTimeStructAccessor(self.struct, IACQFF, ACQFFT, QBMJVH),
            CQFFTT: GeckoEnumStructAccessor(
                self.struct, CQFFTT, QFFTTI, None, TTIDUB, None, None, QBMJVH
            ),
            TIDUBS: GeckoWordStructAccessor(self.struct, TIDUBS, IDUBSS, QBMJVH),
            DUBSSU: GeckoEnumStructAccessor(
                self.struct, DUBSSU, HIUSOO, CWAONP, SSUHBV, None, HBSKSO, QBMJVH
            ),
            SUHBVW: GeckoBoolStructAccessor(
                self.struct, SUHBVW, HIUSOO, UHBVWV, QBMJVH
            ),
            HBVWVU: GeckoEnumStructAccessor(
                self.struct, HBVWVU, HIUSOO, ZILXWA, WVUBYG, None, HBSKSO, QBMJVH
            ),
            VUBYGD: GeckoBoolStructAccessor(
                self.struct, VUBYGD, HIUSOO, UBYGDS, QBMJVH
            ),
            BYGDSB: GeckoBoolStructAccessor(
                self.struct, BYGDSB, HIUSOO, YGDSBD, QBMJVH
            ),
            GDSBDJ: GeckoBoolStructAccessor(
                self.struct, GDSBDJ, DSBDJQ, OOQNRS, QBMJVH
            ),
            SBDJQR: GeckoBoolStructAccessor(
                self.struct, SBDJQR, DSBDJQ, CWAONP, QBMJVH
            ),
            BDJQRJ: GeckoEnumStructAccessor(
                self.struct, BDJQRJ, DSBDJQ, HBSKSO, QRJJJV, None, HBSKSO, QBMJVH
            ),
            RJJJVY: GeckoEnumStructAccessor(
                self.struct, RJJJVY, DSBDJQ, GYOUSP, QRJJJV, None, HBSKSO, QBMJVH
            ),
            JJJVYF: GeckoEnumStructAccessor(
                self.struct, JJJVYF, DSBDJQ, UHBVWV, TFMNHT, None, FMNHTB, QBMJVH
            ),
            MNHTBJ: GeckoEnumStructAccessor(
                self.struct, MNHTBJ, DSBDJQ, YGDSBD, TBJEUT, None, HBSKSO, QBMJVH
            ),
            NRXCHW: GeckoBoolStructAccessor(
                self.struct, NRXCHW, RXCHWD, CWAONP, QBMJVH
            ),
            XCHWDA: GeckoEnumStructAccessor(
                self.struct, XCHWDA, RXCHWD, HBSKSO, WDAFIK, None, UHBVWV, QBMJVH
            ),
            DAFIKJ: GeckoBoolStructAccessor(
                self.struct, DAFIKJ, RXCHWD, UHBVWV, QBMJVH
            ),
            AFIKJP: GeckoByteStructAccessor(self.struct, AFIKJP, FIKJPU, QBMJVH),
            IKJPUN: GeckoBoolStructAccessor(
                self.struct, IKJPUN, THBSKS, OOQNRS, QBMJVH
            ),
            KJPUNR: GeckoByteStructAccessor(self.struct, KJPUNR, JPUNRJ, QBMJVH),
            PUNRJZ: GeckoEnumStructAccessor(
                self.struct, PUNRJZ, UNRJZT, OOQNRS, RJZTAT, None, HBSKSO, None
            ),
            JZTATD: GeckoEnumStructAccessor(
                self.struct, JZTATD, UNRJZT, CWAONP, ATDZXN, None, HBSKSO, None
            ),
            TDZXNQ: GeckoEnumStructAccessor(
                self.struct, TDZXNQ, DZXNQT, OOQNRS, RJZTAT, None, HBSKSO, None
            ),
            ZXNQTM: GeckoEnumStructAccessor(
                self.struct, ZXNQTM, DZXNQT, CWAONP, ATDZXN, None, HBSKSO, None
            ),
            XNQTMF: GeckoEnumStructAccessor(
                self.struct, XNQTMF, NQTMFZ, OOQNRS, RJZTAT, None, HBSKSO, None
            ),
            QTMFZD: GeckoEnumStructAccessor(
                self.struct, QTMFZD, NQTMFZ, CWAONP, ATDZXN, None, HBSKSO, None
            ),
            TMFZDG: GeckoEnumStructAccessor(
                self.struct, TMFZDG, MFZDGK, OOQNRS, RJZTAT, None, HBSKSO, None
            ),
            FZDGKE: GeckoEnumStructAccessor(
                self.struct, FZDGKE, MFZDGK, CWAONP, ATDZXN, None, HBSKSO, None
            ),
            ZDGKEA: GeckoEnumStructAccessor(
                self.struct, ZDGKEA, DGKEAK, OOQNRS, STSEMC, None, FMNHTB, None
            ),
            TSEMCG: GeckoBoolStructAccessor(self.struct, TSEMCG, DGKEAK, YGDSBD, None),
            SEMCGE: GeckoBoolStructAccessor(self.struct, SEMCGE, UNRJZT, UHBVWV, None),
            EMCGET: GeckoBoolStructAccessor(self.struct, EMCGET, UNRJZT, ZILXWA, None),
            MCGETI: GeckoBoolStructAccessor(self.struct, MCGETI, UNRJZT, UBYGDS, None),
            CGETIX: GeckoBoolStructAccessor(self.struct, CGETIX, UNRJZT, YGDSBD, None),
            GETIXQ: GeckoBoolStructAccessor(self.struct, GETIXQ, DZXNQT, UHBVWV, None),
            ETIXQV: GeckoBoolStructAccessor(self.struct, ETIXQV, DZXNQT, ZILXWA, None),
            TIXQVX: GeckoBoolStructAccessor(self.struct, TIXQVX, DZXNQT, UBYGDS, None),
            IXQVXO: GeckoBoolStructAccessor(self.struct, IXQVXO, DZXNQT, YGDSBD, None),
            XQVXOI: GeckoBoolStructAccessor(self.struct, XQVXOI, NQTMFZ, UHBVWV, None),
            QVXOIH: GeckoBoolStructAccessor(self.struct, QVXOIH, NQTMFZ, ZILXWA, None),
            VXOIHB: GeckoBoolStructAccessor(self.struct, VXOIHB, NQTMFZ, UBYGDS, None),
            XOIHBX: GeckoBoolStructAccessor(self.struct, XOIHBX, NQTMFZ, YGDSBD, None),
            OIHBXI: GeckoBoolStructAccessor(self.struct, OIHBXI, MFZDGK, UHBVWV, None),
            IHBXIB: GeckoBoolStructAccessor(self.struct, IHBXIB, MFZDGK, ZILXWA, None),
            HBXIBH: GeckoBoolStructAccessor(self.struct, HBXIBH, MFZDGK, UBYGDS, None),
            BXIBHZ: GeckoBoolStructAccessor(self.struct, BXIBHZ, MFZDGK, YGDSBD, None),
        }



#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'InXE v52'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(chr(c) for c in [65, 76, 87, 65, 89, 83, 95, 79, 78])
AHEOCT = "".join(chr(c) for c in [79, 117, 116, 53, 67, 117, 114])
AIIDNI = "".join(chr(c) for c in [66, 111, 116, 104, 83, 112, 101, 101, 100, 115])
AJVDQL = "".join(chr(c) for c in [65, 109, 80, 109])
AKQXPI = 14
AMJMAO = 70
AOAWBS = 77
AONPYY = 81
ASSAKQ = "".join(chr(c) for c in [79, 117, 116, 50])
AWBSIR = 51
BFEGZU = "".join(chr(c) for c in [79, 117, 116, 49, 49, 67, 117, 114])
BIAMJM = 68
BLKXSJ = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        79,
        110,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49])
BQFYLJ = "".join(chr(c) for c in [73, 110, 112, 117, 116, 77, 101, 110, 117])
BQSNQL = "".join(
    chr(c)
    for c in [83, 111, 97, 107, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
BSIRYX = "".join(chr(c) for c in [67, 69])
BSKSOK = 18
BWJYKL = "".join(chr(c) for c in [84, 111, 103, 103, 108, 101])
BXYBQS = 82
CBFEGZ = 45
CPQIPO = "".join(chr(c) for c in [79, 116, 79, 112, 116, 105, 111, 110])
CQBMJV = 0
CTHBSK = "".join(chr(c) for c in [79, 117, 116, 54])
CVYYPI = "".join(chr(c) for c in [80, 52, 72])
CWAONP = 56
CXQIEF = 26
DNIBXT = "".join(
    chr(c) for c in [83, 101, 108, 102, 67, 108, 101, 97, 110, 77, 115, 103]
)
DQLAII = "".join(
    chr(c)
    for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 84, 114, 105, 103, 65, 68, 67]
)
ECVYYP = "".join(chr(c) for c in [80, 51, 76])
EFXQGL = 36
EGZUQE = "".join(chr(c) for c in [79, 117, 116, 49, 50, 67, 117, 114])
EJNIBX = 71
EKCWAO = 55
EKVKZI = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 83, 108, 97, 118, 101])
EOCTHB = "".join(chr(c) for c in [79, 117, 116, 72, 116, 82, 67, 117, 114])
EXLSXU = 49
FEFJTA = "".join(chr(c) for c in [70, 105, 108, 116, 80, 49])
FEGZUQ = 46
FJBIAM = 66
FJTACC = "".join(chr(c) for c in [67, 112, 85, 115, 97, 103, 101])
FTHECV = "".join(chr(c) for c in [80, 50, 72])
FTSIFJ = 31
FWRKIN = 6
FXQGLR = "".join(chr(c) for c in [79, 117, 116, 50, 67, 117, 114])
FYLJUI = "".join(chr(c) for c in [68, 117, 97, 108, 80, 97, 99, 107])
GLRAHE = 38
GQPLSP = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
GYOUSP = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
GZUQEX = 47
HBSKSO = "".join(chr(c) for c in [79, 117, 116, 55])
HECVYY = "".join(chr(c) for c in [80, 51, 72])
HEOCTH = 40
HFTHEC = "".join(chr(c) for c in [80, 49, 76])
HUOJRJ = "".join(chr(c) for c in [79, 117, 116, 49, 49])
HXEKVK = "".join(chr(c) for c in [66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67])
IAMJMA = "".join(chr(c) for c in [69, 99, 111, 110, 84, 121, 112, 101])
IBXYBQ = "".join(chr(c) for c in [85, 68, 80, 114, 111, 103, 69, 99, 111, 110])
ICXQIE = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114])
IEFXQG = "".join(chr(c) for c in [79, 117, 116, 49, 67, 117, 114])
IFJBIA = "".join(
    chr(c) for c in [77, 105, 110, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
IIDNIB = "".join(
    chr(c) for c in [72, 105, 103, 104, 83, 112, 101, 101, 100, 79, 110, 108, 121]
)
IKFWRK = 4
ILXWAJ = "".join(chr(c) for c in [83, 108, 97, 118, 101, 67, 111, 110, 102, 105, 103])
INEJNI = 10
IPIVLA = "".join(chr(c) for c in [79, 51])
IPOUYN = "".join(
    chr(c) for c in [65, 108, 119, 97, 121, 115, 69, 110, 97, 98, 108, 101, 100]
)
IRYXBQ = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
IUSOOQ = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 50])
IUXFEF = 32
IVLASS = "".join(chr(c) for c in [])
JBIAMJ = "".join(
    chr(c) for c in [77, 97, 120, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
JHIUSO = 24
JIGYOU = "".join(chr(c) for c in [65, 108, 119, 97, 121, 115])
JMCBFE = 44
JNIBXY = "".join(chr(c) for c in [65, 118, 97, 105, 108, 97, 98, 108, 101])
JRJHIU = 23
JTACCP = 27
JUIKFW = 3
JUTYEK = 80
JVDQLA = "".join(chr(c) for c in [50, 52, 104])
JVHFTH = "".join(chr(c) for c in [78, 65])
JWMNZM = 78
JYKLGQ = "".join(
    chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
JYMOUN = "".join(chr(c) for c in [79, 84, 84, 114, 105, 103, 103, 101, 114, 71])
KCWAON = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 79, 117, 116])
KFWRKI = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114])
KINEJN = "".join(chr(c) for c in [69, 99, 111, 110, 68, 117, 114])
KLGQPL = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
KPHUOJ = "".join(chr(c) for c in [79, 117, 116, 49, 48])
KQXPIC = "".join(chr(c) for c in [79, 117, 116, 52])
KSOKPH = 19
KVKZIL = 73
KXSJWM = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
KZILXW = "".join(chr(c) for c in [83, 108, 97, 118, 101])
LAIIDN = "".join(
    chr(c)
    for c in [80, 117, 109, 112, 49, 85, 115, 101, 114, 65, 99, 99, 101, 115, 115]
)
LGQPLS = 1
LIUXFE = "".join(
    chr(c) for c in [70, 105, 108, 116, 73, 110, 116, 101, 114, 102, 97, 99, 101]
)
LJUIKF = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
LKXSJW = 61
LNMHXE = "".join(
    chr(c) for c in [77, 117, 108, 116, 105, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
LRAHEO = "".join(chr(c) for c in [79, 117, 116, 52, 67, 117, 114])
LSPFTS = "".join(chr(c) for c in [67])
LSXUJU = 79
LXWAJV = 75
MAOAWB = "".join(
    chr(c) for c in [78, 111, 72, 101, 97, 116, 80, 101, 114, 105, 111, 100]
)
MCBFEG = "".join(chr(c) for c in [79, 117, 116, 49, 48, 67, 117, 114])
MHXEKV = "".join(
    chr(c) for c in [78, 111, 66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67]
)
MJIGYO = "".join(chr(c) for c in [70, 105, 108, 116, 101, 114])
MJMAOA = "".join(chr(c) for c in [78, 105, 103, 104, 116])
MJVHFT = 12
MOUNBL = "".join(
    chr(c)
    for c in [67, 112, 79, 110, 84, 105, 109, 101, 68, 117, 114, 105, 110, 103, 79, 84]
)
NBLKXS = 60
NEJNIB = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        80,
        114,
        111,
        103,
        65,
        118,
        97,
        105,
        108,
        97,
        98,
        108,
        101,
    ]
)
NIBXTI = 4
NMHXEK = 76
NPYYLI = "".join(chr(c) for c in [79, 119, 110])
NQJYMO = "".join(chr(c) for c in [72, 105])
NQLNMH = "".join(
    chr(c)
    for c in [
        67,
        108,
        101,
        97,
        110,
        117,
        112,
        79,
        110,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
NRSJMC = "".join(chr(c) for c in [79, 117, 116, 56, 67, 117, 114])
NZMJIG = "".join(chr(c) for c in [79, 51, 85, 115, 97, 103, 101])
OAWBSI = "".join(chr(c) for c in [85, 76, 95, 67, 69])
OCTHBS = 50
OJRJHI = "".join(chr(c) for c in [79, 117, 116, 49, 50])
OKPHUO = 20
ONPYYL = "".join(chr(c) for c in [83, 104, 97, 114, 101, 100])
OOQNRS = 41
OQNRSJ = "".join(chr(c) for c in [79, 117, 116, 55, 67, 117, 114])
OUNBLK = 59
PBWJYK = "".join(chr(c) for c in [83, 116, 97, 110, 100, 97, 114, 100])
PFTSIF = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
PHUOJR = 21
PICXQI = 16
PIPIVL = "".join(chr(c) for c in [67, 80])
PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
PLSPFT = "".join(chr(c) for c in [70])
POUYNQ = "".join(
    chr(c) for c in [87, 105, 116, 104, 83, 80, 79, 118, 101, 114, 57, 53, 70]
)
PQIPOU = 57
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QEXLSX = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 50, 67, 117, 114])
QFYLJU = 74
QGLRAH = "".join(chr(c) for c in [79, 117, 116, 51, 67, 117, 114])
QIPOUY = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101, 100])
QLAIID = 64
QLNMHX = 3
QNRSJM = 42
QPLSPF = 33
QSNQLN = "".join(
    chr(c) for c in [79, 102, 102, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
QXPICX = 15
RAHEOC = 39
RJHIUS = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116])
RKINEJ = 8
RSJMCB = 43
RYXBQF = 52
SAKQXP = "".join(chr(c) for c in [79, 117, 116, 51])
SIFJBI = 35
SJMCBF = "".join(chr(c) for c in [79, 117, 116, 57, 67, 117, 114])
SJWMNZ = "".join(chr(c) for c in [68, 114, 97, 105, 110, 77, 111, 100, 101])
SKSOKP = "".join(chr(c) for c in [79, 117, 116, 56])
SNQLNM = 1
SOKPHU = "".join(chr(c) for c in [79, 117, 116, 57])
SOOQNR = "".join(chr(c) for c in [79, 117, 116, 54, 67, 117, 114])
SPBWJY = 30
SSAKQX = 13
SXUJUT = "".join(chr(c) for c in [76, 73])
TACCPQ = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
THBSKS = 17
THECVY = "".join(chr(c) for c in [80, 50, 76])
TIACQF = 52
TSIFJB = "".join(
    chr(c) for c in [67, 111, 111, 108, 100, 111, 119, 110, 84, 105, 109, 101]
)
TYEKCW = 54
UIKFWR = "".join(chr(c) for c in [70, 105, 108, 116, 83, 116, 97, 114, 116])
UJUTYE = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
UNBLKX = "".join(
    chr(c)
    for c in [
        67,
        112,
        79,
        102,
        102,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
UOJRJH = 22
UQEXLS = 48
USOOQN = 25
USPBWJ = "".join(chr(c) for c in [79, 51, 84, 121, 112, 101])
UTYEKC = "".join(chr(c) for c in [80, 117, 109, 112, 84, 105, 109, 101, 79, 117, 116])
UXFEFJ = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
UYNQJY = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 112, 101, 101, 100])
VHFTHE = "".join(chr(c) for c in [80, 49, 72])
VKZILX = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114])
VLASSA = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
VYYPIP = "".join(chr(c) for c in [80, 52, 76])
WAJVDQ = 34
WAONPY = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 114])
WBSIRY = "".join(chr(c) for c in [85, 76])
WMNZMJ = "".join(chr(c) for c in [80, 49])
WRKINE = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 97, 114, 116])
XBQFYL = 53
XFEFJT = "".join(chr(c) for c in [70, 105, 108, 116, 67, 80])
XLSXUJ = "".join(chr(c) for c in [79, 117, 116, 76, 105])
XPICXQ = "".join(chr(c) for c in [79, 117, 116, 53])
XQGLRA = 37
XQIEFX = "".join(chr(c) for c in [72, 84, 82])
XSJWMN = 62
XWAJVD = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
XYBQSN = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        67,
        111,
        110,
        116,
        114,
        111,
        108,
        97,
        98,
        108,
        101,
        77,
        97,
        110,
        117,
        97,
        108,
        108,
        121,
    ]
)
YBQSNQ = 72
YEKCWA = "".join(
    chr(c) for c in [76, 105, 103, 104, 116, 84, 105, 109, 101, 79, 117, 116]
)
YKLGQP = 63
YLIUXF = 2
YMOUNB = 58
YNQJYM = "".join(chr(c) for c in [76, 111])
YOUSPB = 29
YPIPIV = "".join(chr(c) for c in [66, 76, 79])
YXBQFY = "".join(
    chr(c) for c in [73, 110, 112, 117, 116, 67, 117, 114, 114, 101, 110, 116]
)
YYLIUX = 0
YYPIPI = "".join(chr(c) for c in [80, 53])
ZCQBMJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
)
ZMJIGY = 28
ZUQEXL = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 67, 117, 114])
BXTIAC = [SXUJUT]
CCPQIP = [TACCPQ, ACCPQI]
EFJTAC = [UXFEFJ, XFEFJT, FEFJTA]
HIUSOO = [
    JVHFTH,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    PIPIVL,
]
IBXTIA = [
    BMJVHF,
    ASSAKQ,
    SAKQXP,
    KQXPIC,
    XPICXQ,
    ICXQIE,
    CTHBSK,
    HBSKSO,
    SKSOKP,
    SOKPHU,
    KPHUOJ,
    HUOJRJ,
    OJRJHI,
    RJHIUS,
    IUSOOQ,
    XLSXUJ,
]
IDNIBX = [AIIDNI, IIDNIB]
IGYOUS = [MJIGYO, JIGYOU]
JMAOAW = [PBWJYK, MJMAOA]
LASSAK = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    VLASSA,
]
MNZMJI = [JVHFTH, WMNZMJ, PIPIVL]
NIBXYB = [JVHFTH, JNIBXY]
OUSPBW = [PIPIVL, WMNZMJ]
OUYNQJ = [QIPOUY, IPOUYN, POUYNQ]
PYYLIU = [ONPYYL, NPYYLI]
QIEFXQ = [
    JVHFTH,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    XQIEFX,
]
QJYMOU = [YNQJYM, NQJYMO]
SIRYXB = [WBSIRY, BSIRYX]
SPFTSI = [PLSPFT, LSPFTS]
VDQLAI = [JVHFTH, AJVDQL, JVDQLA]
WJYKLG = [PBWJYK, BWJYKL]
XEKVKZ = [MHXEKV, HXEKVK]
XTIACQ = []
XUJUTY = [
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    SXUJUT,
]
YLJUIK = [PBWJYK, FYLJUI]
ZILXWA = [IVLASS, VKZILX, KZILXW]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return TIACQF

    @property
    def output_keys(self):
        return IBXTIA

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, LASSAK, None, None, QBMJVH
            ),
            ASSAKQ: GeckoEnumStructAccessor(
                self.struct, ASSAKQ, SSAKQX, None, LASSAK, None, None, QBMJVH
            ),
            SAKQXP: GeckoEnumStructAccessor(
                self.struct, SAKQXP, AKQXPI, None, LASSAK, None, None, QBMJVH
            ),
            KQXPIC: GeckoEnumStructAccessor(
                self.struct, KQXPIC, QXPICX, None, LASSAK, None, None, QBMJVH
            ),
            XPICXQ: GeckoEnumStructAccessor(
                self.struct, XPICXQ, PICXQI, None, LASSAK, None, None, QBMJVH
            ),
            ICXQIE: GeckoEnumStructAccessor(
                self.struct, ICXQIE, CXQIEF, None, QIEFXQ, None, None, QBMJVH
            ),
            IEFXQG: GeckoByteStructAccessor(self.struct, IEFXQG, EFXQGL, QBMJVH),
            FXQGLR: GeckoByteStructAccessor(self.struct, FXQGLR, XQGLRA, QBMJVH),
            QGLRAH: GeckoByteStructAccessor(self.struct, QGLRAH, GLRAHE, QBMJVH),
            LRAHEO: GeckoByteStructAccessor(self.struct, LRAHEO, RAHEOC, QBMJVH),
            AHEOCT: GeckoByteStructAccessor(self.struct, AHEOCT, HEOCTH, QBMJVH),
            EOCTHB: GeckoByteStructAccessor(self.struct, EOCTHB, OCTHBS, QBMJVH),
            CTHBSK: GeckoEnumStructAccessor(
                self.struct, CTHBSK, THBSKS, None, LASSAK, None, None, QBMJVH
            ),
            HBSKSO: GeckoEnumStructAccessor(
                self.struct, HBSKSO, BSKSOK, None, LASSAK, None, None, QBMJVH
            ),
            SKSOKP: GeckoEnumStructAccessor(
                self.struct, SKSOKP, KSOKPH, None, LASSAK, None, None, QBMJVH
            ),
            SOKPHU: GeckoEnumStructAccessor(
                self.struct, SOKPHU, OKPHUO, None, LASSAK, None, None, QBMJVH
            ),
            KPHUOJ: GeckoEnumStructAccessor(
                self.struct, KPHUOJ, PHUOJR, None, LASSAK, None, None, QBMJVH
            ),
            HUOJRJ: GeckoEnumStructAccessor(
                self.struct, HUOJRJ, UOJRJH, None, LASSAK, None, None, QBMJVH
            ),
            OJRJHI: GeckoEnumStructAccessor(
                self.struct, OJRJHI, JRJHIU, None, LASSAK, None, None, QBMJVH
            ),
            RJHIUS: GeckoEnumStructAccessor(
                self.struct, RJHIUS, JHIUSO, None, HIUSOO, None, None, QBMJVH
            ),
            IUSOOQ: GeckoEnumStructAccessor(
                self.struct, IUSOOQ, USOOQN, None, HIUSOO, None, None, QBMJVH
            ),
            SOOQNR: GeckoByteStructAccessor(self.struct, SOOQNR, OOQNRS, QBMJVH),
            OQNRSJ: GeckoByteStructAccessor(self.struct, OQNRSJ, QNRSJM, QBMJVH),
            NRSJMC: GeckoByteStructAccessor(self.struct, NRSJMC, RSJMCB, QBMJVH),
            SJMCBF: GeckoByteStructAccessor(self.struct, SJMCBF, JMCBFE, QBMJVH),
            MCBFEG: GeckoByteStructAccessor(self.struct, MCBFEG, CBFEGZ, QBMJVH),
            BFEGZU: GeckoByteStructAccessor(self.struct, BFEGZU, FEGZUQ, QBMJVH),
            EGZUQE: GeckoByteStructAccessor(self.struct, EGZUQE, GZUQEX, QBMJVH),
            ZUQEXL: GeckoByteStructAccessor(self.struct, ZUQEXL, UQEXLS, QBMJVH),
            QEXLSX: GeckoByteStructAccessor(self.struct, QEXLSX, EXLSXU, QBMJVH),
            XLSXUJ: GeckoEnumStructAccessor(
                self.struct, XLSXUJ, LSXUJU, None, XUJUTY, None, None, None
            ),
            UJUTYE: GeckoByteStructAccessor(self.struct, UJUTYE, JUTYEK, None),
            UTYEKC: GeckoByteStructAccessor(self.struct, UTYEKC, TYEKCW, QBMJVH),
            YEKCWA: GeckoByteStructAccessor(self.struct, YEKCWA, EKCWAO, QBMJVH),
            KCWAON: GeckoByteStructAccessor(self.struct, KCWAON, CWAONP, QBMJVH),
            WAONPY: GeckoEnumStructAccessor(
                self.struct, WAONPY, AONPYY, YYLIUX, PYYLIU, None, YLIUXF, QBMJVH
            ),
            LIUXFE: GeckoEnumStructAccessor(
                self.struct, LIUXFE, IUXFEF, None, EFJTAC, None, None, QBMJVH
            ),
            FJTACC: GeckoEnumStructAccessor(
                self.struct, FJTACC, JTACCP, None, CCPQIP, None, None, QBMJVH
            ),
            CPQIPO: GeckoEnumStructAccessor(
                self.struct, CPQIPO, PQIPOU, None, OUYNQJ, None, None, QBMJVH
            ),
            UYNQJY: GeckoEnumStructAccessor(
                self.struct, UYNQJY, AONPYY, YLIUXF, QJYMOU, None, YLIUXF, QBMJVH
            ),
            JYMOUN: GeckoByteStructAccessor(self.struct, JYMOUN, YMOUNB, QBMJVH),
            MOUNBL: GeckoByteStructAccessor(self.struct, MOUNBL, OUNBLK, QBMJVH),
            UNBLKX: GeckoByteStructAccessor(self.struct, UNBLKX, NBLKXS, QBMJVH),
            BLKXSJ: GeckoByteStructAccessor(self.struct, BLKXSJ, LKXSJW, QBMJVH),
            KXSJWM: GeckoByteStructAccessor(self.struct, KXSJWM, XSJWMN, QBMJVH),
            SJWMNZ: GeckoEnumStructAccessor(
                self.struct, SJWMNZ, JWMNZM, None, MNZMJI, None, None, QBMJVH
            ),
            NZMJIG: GeckoEnumStructAccessor(
                self.struct, NZMJIG, ZMJIGY, None, IGYOUS, None, None, QBMJVH
            ),
            GYOUSP: GeckoEnumStructAccessor(
                self.struct, GYOUSP, YOUSPB, None, OUSPBW, None, None, QBMJVH
            ),
            USPBWJ: GeckoEnumStructAccessor(
                self.struct, USPBWJ, SPBWJY, None, WJYKLG, None, None, QBMJVH
            ),
            JYKLGQ: GeckoByteStructAccessor(self.struct, JYKLGQ, YKLGQP, QBMJVH),
            KLGQPL: GeckoTempStructAccessor(self.struct, KLGQPL, LGQPLS, QBMJVH),
            GQPLSP: GeckoEnumStructAccessor(
                self.struct, GQPLSP, QPLSPF, None, SPFTSI, None, None, QBMJVH
            ),
            PFTSIF: GeckoEnumStructAccessor(
                self.struct, PFTSIF, FTSIFJ, None, OUSPBW, None, None, QBMJVH
            ),
            TSIFJB: GeckoByteStructAccessor(self.struct, TSIFJB, SIFJBI, QBMJVH),
            IFJBIA: GeckoTempStructAccessor(self.struct, IFJBIA, FJBIAM, QBMJVH),
            JBIAMJ: GeckoTempStructAccessor(self.struct, JBIAMJ, BIAMJM, QBMJVH),
            IAMJMA: GeckoEnumStructAccessor(
                self.struct, IAMJMA, AMJMAO, None, JMAOAW, None, None, QBMJVH
            ),
            MAOAWB: GeckoByteStructAccessor(self.struct, MAOAWB, AOAWBS, QBMJVH),
            OAWBSI: GeckoEnumStructAccessor(
                self.struct, OAWBSI, AWBSIR, None, SIRYXB, None, None, QBMJVH
            ),
            IRYXBQ: GeckoByteStructAccessor(self.struct, IRYXBQ, RYXBQF, QBMJVH),
            YXBQFY: GeckoByteStructAccessor(self.struct, YXBQFY, XBQFYL, QBMJVH),
            BQFYLJ: GeckoEnumStructAccessor(
                self.struct, BQFYLJ, QFYLJU, None, YLJUIK, None, None, QBMJVH
            ),
            LJUIKF: GeckoByteStructAccessor(self.struct, LJUIKF, JUIKFW, QBMJVH),
            UIKFWR: GeckoTimeStructAccessor(self.struct, UIKFWR, IKFWRK, QBMJVH),
            KFWRKI: GeckoTimeStructAccessor(self.struct, KFWRKI, FWRKIN, QBMJVH),
            WRKINE: GeckoTimeStructAccessor(self.struct, WRKINE, RKINEJ, QBMJVH),
            KINEJN: GeckoTimeStructAccessor(self.struct, KINEJN, INEJNI, QBMJVH),
            NEJNIB: GeckoEnumStructAccessor(
                self.struct, NEJNIB, EJNIBX, None, NIBXYB, None, None, QBMJVH
            ),
            IBXYBQ: GeckoBoolStructAccessor(
                self.struct, IBXYBQ, BXYBQS, YYLIUX, QBMJVH
            ),
            XYBQSN: GeckoBoolStructAccessor(
                self.struct, XYBQSN, YBQSNQ, YLIUXF, QBMJVH
            ),
            BQSNQL: GeckoBoolStructAccessor(
                self.struct, BQSNQL, YBQSNQ, YYLIUX, QBMJVH
            ),
            QSNQLN: GeckoBoolStructAccessor(
                self.struct, QSNQLN, YBQSNQ, SNQLNM, QBMJVH
            ),
            NQLNMH: GeckoBoolStructAccessor(
                self.struct, NQLNMH, YBQSNQ, QLNMHX, QBMJVH
            ),
            LNMHXE: GeckoEnumStructAccessor(
                self.struct, LNMHXE, NMHXEK, None, XEKVKZ, None, None, QBMJVH
            ),
            EKVKZI: GeckoEnumStructAccessor(
                self.struct, EKVKZI, KVKZIL, None, ZILXWA, None, None, QBMJVH
            ),
            ILXWAJ: GeckoByteStructAccessor(self.struct, ILXWAJ, LXWAJV, QBMJVH),
            XWAJVD: GeckoEnumStructAccessor(
                self.struct, XWAJVD, WAJVDQ, None, VDQLAI, None, None, QBMJVH
            ),
            DQLAII: GeckoWordStructAccessor(self.struct, DQLAII, QLAIID, QBMJVH),
            LAIIDN: GeckoEnumStructAccessor(
                self.struct, LAIIDN, AONPYY, SNQLNM, IDNIBX, None, YLIUXF, QBMJVH
            ),
            DNIBXT: GeckoBoolStructAccessor(
                self.struct, DNIBXT, AONPYY, NIBXTI, QBMJVH
            ),
        }



"""AsyncTasks is a class to farm intenal new tasks out to an awaiter"""

import logging
import asyncio
from .const import GeckoConstants

_LOGGER = logging.getLogger(__name__)


class AsyncTasks:
    def __init__(self):
        self._tasks = []

    async def __aenter__(self):
        self.add_task(self._tidy(), "Tidy tasks", "ASYNC")

    async def __aexit__(self, *exc_info) -> None:
        await self.gather()

    def add_task(self, coroutine, name_: str, key_: str) -> None:
        _LOGGER.debug("Starting task `%s` in domain `%s`", name_, key_)
        task = asyncio.create_task(coroutine, name=f"{key_}:{name_}")
        self._tasks.append(task)

    def cancel_key_tasks(self, key_: str) -> None:
        for task in self._tasks:
            if task.get_name().startswith(f"{key_}:"):
                _LOGGER.debug("Cancel task %s", task)
                task.cancel()

    async def gather(self) -> None:
        # Cancel all tasks
        for task in self._tasks:
            _LOGGER.debug("Cancel task %s", task)
            task.cancel()
        # Wait for all tasks to complete
        _results = await asyncio.gather(*self._tasks, return_exceptions=True)
        for item in zip(self._tasks, _results):
            _LOGGER.debug("    Task %s result `%r`", item[0].get_name(), item[1])

    async def _tidy(self) -> None:
        try:
            while True:
                # Run every five seconds
                await asyncio.sleep(GeckoConstants.TASK_TIDY_FREQUENCY_IN_SECONDS)
                if _LOGGER.isEnabledFor(logging.DEBUG):
                    for task in self._tasks:
                        if task.done():
                            _LOGGER.debug("Tidy task %s", task)
                self._tasks = [task for task in self._tasks if not task.done()]
        except asyncio.CancelledError:
            _LOGGER.debug("Tidy loop cancelled")
            raise

    @property
    def unique_id(self) -> str:
        """Dummy function designed to be overridden"""
        return ""

    @property
    def spa_name(self) -> str:
        """Dummy function designed to be overridden"""
        return ""



""" Gecko AVERS/SVERS handlers """

import logging
import struct

from .packet import GeckoPacketProtocolHandler

AVERS_VERB = b"AVERS"
SVERS_VERB = b"SVERS"
VERSION_FORMAT = ">HBBHBB"

_LOGGER = logging.getLogger(__name__)


class GeckoVersionProtocolHandler(GeckoPacketProtocolHandler):
    @staticmethod
    def request(seq, **kwargs):
        return GeckoVersionProtocolHandler(
            content=b"".join([AVERS_VERB, struct.pack(">B", seq)]),
            timeout=2,
            retry_count=10,
            on_retry_failed=GeckoPacketProtocolHandler._default_retry_failed_handler,
            **kwargs,
        )

    @staticmethod
    def response(intouch_EN: tuple, intouch_CO: tuple, **kwargs):
        return GeckoVersionProtocolHandler(
            content=b"".join(
                [
                    SVERS_VERB,
                    struct.pack(
                        VERSION_FORMAT,
                        *intouch_EN,
                        *intouch_CO,
                    ),
                ]
            ),
            **kwargs,
        )

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.en_build = self.en_major = self.en_minor = None
        self.co_build = self.co_major = self.co_minor = None

    def can_handle(self, received_bytes: bytes, sender: tuple) -> bool:
        return received_bytes.startswith(AVERS_VERB) or received_bytes.startswith(
            SVERS_VERB
        )

    def handle(self, received_bytes: bytes, sender: tuple):
        remainder = received_bytes[5:]
        if received_bytes.startswith(AVERS_VERB):
            self._sequence = struct.unpack(">B", remainder)[0]
            return
        # Otherwise must be SVERS
        (
            self.en_build,
            self.en_major,
            self.en_minor,
            self.co_build,
            self.co_major,
            self.co_minor,
        ) = struct.unpack(VERSION_FORMAT, remainder)
        self._should_remove_handler = True



""" Async Spa Structure block """

import logging


_LOGGER = logging.getLogger(__name__)


class GeckoAsyncStructure:
    """Class to host/manage the raw data block for a spa structure"""

    def __init__(self, on_set_value, on_async_set_value):
        self._on_set_value = on_set_value
        self._on_async_set_value = on_async_set_value
        self.accessors = {}
        self.reset()

    def replace_status_block_segment(self, offset, segment):
        """Replace a segment of the status block"""
        previous_block = self._status_block
        segment_len = len(segment)
        self._status_block = (
            self._status_block[0:offset]
            + segment
            + self._status_block[offset + segment_len :]
        )
        # Notify changes to accessors
        for accessor in self.accessors.values():
            accessor.status_block_changed(offset, segment_len, previous_block)

    @property
    def status_block(self):
        return self._status_block

    def set_status_block(self, block):
        self._status_block = block

    def build_accessors(self, config_class, log_class):
        self.accessors = dict(config_class.accessors, **log_class.accessors)
        # Get all outputs
        self.all_outputs = config_class.output_keys
        # Get collection of possible devices
        self.all_devices = log_class.all_device_keys
        # User devices are those that have a Ud in the tag name
        self.user_demands = log_class.user_demand_keys

    def reset(self) -> None:
        """Reset this status block to initialization state"""
        self.accessors = {}
        self.all_outputs = []
        self.all_devices = []
        self.user_demands = []
        self._status_block = b"\x00" * 1024

    async def get(self, protocol, create_func, retry_count=10):
        _LOGGER.debug("Async get for struct, acquire the lock")
        async with protocol.Lock:
            _LOGGER.debug("Lock acquired")

            while retry_count > 0:

                # Create the request
                request = create_func()

                # Queue it for delivery
                protocol.queue_send(request)

                # Setup some controls for the multiple responses expected
                next_expected = 0
                segments = []

                while True:

                    # Wait for a response up to a certain amount of time
                    if await request.wait_for_response(protocol):

                        if next_expected == request.sequence:

                            segments.append(request.data)
                            next_expected = request.next

                            if request.next == 0:

                                _LOGGER.debug(
                                    (
                                        "Status block segments complete, "
                                        "update and complete"
                                    )
                                )

                                self.replace_status_block_segment(
                                    request.start,
                                    b"".join(segments),
                                )

                                return True

                        else:

                            _LOGGER.debug(
                                "Out-of-sequence status block segment %d - ignored",
                                request.sequence,
                            )

                            if request.next == 0:
                                break

                    else:

                        _LOGGER.debug("timeout waiting for any block")
                        break

                retry_count -= 1
            return False

    def set_value(self, pos, length, newvalue):
        # Delegate this
        self._on_set_value(pos, length, newvalue)

    async def async_set_value(self, pos, length, newvalue):
        # Delegate this
        await self._on_async_set_value(pos, length, newvalue)
